@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2015-2022, Intel Corporation */
+/* Copyright 2015-2023, Intel Corporation */
 
 /*
  * pmembench.cpp -- main source file for benchmark framework
@@ -1215,9 +1215,10 @@ scale_up_min_exe_time(struct benchmark *bench, struct benchmark_args *args,
 		 * scale up number of operations to get assumed minimal
 		 * execution time
 		 */
-		args->n_ops_per_thread = (size_t)(
-			(double)args->n_ops_per_thread *
-			(min_exe_time + MIN_EXE_TIME_E) / total_res->total.min);
+		args->n_ops_per_thread =
+			(size_t)((double)args->n_ops_per_thread *
+				 (min_exe_time + MIN_EXE_TIME_E) /
+				 total_res->total.min);
 
 		results_free(total_res);
 		*total_results = results_alloc(args);
@@ -1620,14 +1621,3 @@ out:
 	util_mmap_fini();
 	return ret;
 }
-
-#ifdef _MSC_VER
-extern "C" {
-/*
- * Since libpmemobj is linked statically,
- * we need to invoke its ctor/dtor.
- */
-MSVC_CONSTR(libpmemobj_init)
-MSVC_DESTR(libpmemobj_fini)
-}
-#endif
