@@ -1,34 +1,5 @@
-/*
- * Copyright 2014-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2014-2024, Intel Corporation */
 
 /*
  * mmap.c -- mmap utilities
@@ -48,6 +19,7 @@
 #include "sys_util.h"
 #include "os.h"
 #include "alloc.h"
+#include "libpmem2.h"
 
 int Mmap_no_random;
 void *Mmap_hint;
@@ -79,9 +51,9 @@ util_mmap_init(void)
 		unsigned long long val = strtoull(e, &endp, 16);
 
 		if (errno || endp == e) {
-			LOG(2, "Invalid PMEM_MMAP_HINT");
+			CORE_LOG_WARNING("Invalid PMEM_MMAP_HINT");
 		} else if (os_access(OS_MAPFILE, R_OK)) {
-			LOG(2, "No /proc, PMEM_MMAP_HINT ignored");
+			CORE_LOG_WARNING("No /proc, PMEM_MMAP_HINT ignored");
 		} else {
 			Mmap_hint = (void *)val;
 			Mmap_no_random = 1;
@@ -119,7 +91,7 @@ util_map(int fd, os_off_t off, size_t len, int flags, int rdonly,
 	void *base;
 	void *addr = util_map_hint(len, req_align);
 	if (addr == MAP_FAILED) {
-		LOG(1, "cannot find a contiguous region of given size");
+		CORE_LOG_ERROR("cannot find a contiguous region of given size");
 		return NULL;
 	}
 
@@ -129,7 +101,7 @@ util_map(int fd, os_off_t off, size_t len, int flags, int rdonly,
 	int proto = rdonly ? PROT_READ : PROT_READ|PROT_WRITE;
 	base = util_map_sync(addr, len, proto, flags, fd, off, map_sync);
 	if (base == MAP_FAILED) {
-		ERR("!mmap %zu bytes", len);
+		ERR_W_ERRNO("mmap %zu bytes", len);
 		return NULL;
 	}
 
@@ -149,19 +121,9 @@ util_unmap(void *addr, size_t len)
 {
 	LOG(3, "addr %p len %zu", addr, len);
 
-/*
- * XXX Workaround for https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=169608
- */
-#ifdef __FreeBSD__
-	if (!IS_PAGE_ALIGNED((uintptr_t)addr)) {
-		errno = EINVAL;
-		ERR("!munmap");
-		return -1;
-	}
-#endif
 	int retval = munmap(addr, len);
 	if (retval < 0)
-		ERR("!munmap");
+		ERR_W_ERRNO("munmap");
 
 	return retval;
 }
@@ -190,7 +152,7 @@ util_range_ro(void *addr, size_t len)
 	uptr = (uintptr_t)addr & ~(Pagesize - 1);
 
 	if ((retval = mprotect((void *)uptr, len, PROT_READ)) < 0)
-		ERR("!mprotect: PROT_READ");
+		ERR_W_ERRNO("mprotect: PROT_READ");
 
 	return retval;
 }
@@ -219,7 +181,7 @@ util_range_rw(void *addr, size_t len)
 	uptr = (uintptr_t)addr & ~(Pagesize - 1);
 
 	if ((retval = mprotect((void *)uptr, len, PROT_READ|PROT_WRITE)) < 0)
-		ERR("!mprotect: PROT_READ|PROT_WRITE");
+		ERR_W_ERRNO("mprotect: PROT_READ|PROT_WRITE");
 
 	return retval;
 }
@@ -248,7 +210,7 @@ util_range_none(void *addr, size_t len)
 	uptr = (uintptr_t)addr & ~(Pagesize - 1);
 
 	if ((retval = mprotect((void *)uptr, len, PROT_NONE)) < 0)
-		ERR("!mprotect: PROT_NONE");
+		ERR_W_ERRNO("mprotect: PROT_NONE");
 
 	return retval;
 }
@@ -322,7 +284,7 @@ util_range_register(const void *addr, size_t len, const char *path,
 
 	/* check if not tracked already */
 	if (util_range_find((uintptr_t)addr, len) != NULL) {
-		ERR(
+		ERR_WO_ERRNO(
 		"duplicated persistent memory range; presumably unmapped with munmap() instead of pmem_unmap(): addr %p len %zu",
 			addr, len);
 		errno = ENOMEM;
@@ -332,15 +294,22 @@ util_range_register(const void *addr, size_t len, const char *path,
 	struct map_tracker *mt;
 	mt  = Malloc(sizeof(struct map_tracker));
 	if (mt == NULL) {
-		ERR("!Malloc");
+		ERR_W_ERRNO("Malloc");
 		return -1;
 	}
 
 	mt->base_addr = (uintptr_t)addr;
 	mt->end_addr = mt->base_addr + len;
 	mt->type = type;
-	if (type == PMEM_DEV_DAX)
-		mt->region_id = util_ddax_region_find(path);
+	if (type == PMEM_DEV_DAX) {
+		unsigned region_id;
+		int ret = util_ddax_region_find(path, &region_id);
+		if (ret < 0) {
+			ERR_WO_ERRNO("Cannot find DAX device region id");
+			return -1;
+		}
+		mt->region_id = region_id;
+	}
 
 	util_rwlock_wrlock(&Mmap_list_lock);
 
@@ -364,7 +333,7 @@ util_range_split(struct map_tracker *mt, const void *addrp, const void *endp)
 	uintptr_t end = (uintptr_t)endp;
 	ASSERTne(mt, NULL);
 	if (addr == end || addr % Mmap_align != 0 || end % Mmap_align != 0) {
-		ERR(
+		ERR_WO_ERRNO(
 		"invalid munmap length, must be non-zero and page aligned");
 		return -1;
 	}
@@ -388,7 +357,7 @@ util_range_split(struct map_tracker *mt, const void *addrp, const void *endp)
 		/* new mapping at the beginning */
 		mtb = Malloc(sizeof(struct map_tracker));
 		if (mtb == NULL) {
-			ERR("!Malloc");
+			ERR_W_ERRNO("Malloc");
 			goto err;
 		}
 
@@ -403,7 +372,7 @@ util_range_split(struct map_tracker *mt, const void *addrp, const void *endp)
 		/* new mapping at the end */
 		mte = Malloc(sizeof(struct map_tracker));
 		if (mte == NULL) {
-			ERR("!Malloc");
+			ERR_W_ERRNO("Malloc");
 			goto err;
 		}
 
