@@ -1,5 +1,5 @@
-// SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2014-2020, Intel Corporation */
+/* SPDX-License-Identifier: BSD-3-Clause */
+/* Copyright 2014-2023, Intel Corporation */
 
 /*
  * mmap.h -- internal definitions for mmap module
@@ -33,12 +33,7 @@ void *util_map(int fd, os_off_t off, size_t len, int flags, int rdonly,
 		size_t req_align, int *map_sync);
 int util_unmap(void *addr, size_t len);
 
-#ifdef __FreeBSD__
-#define MAP_NORESERVE 0
-#define OS_MAPFILE "/proc/curproc/map"
-#else
 #define OS_MAPFILE "/proc/self/maps"
-#endif
 
 #ifndef MAP_SYNC
 #define MAP_SYNC 0x80000
@@ -84,14 +79,6 @@ struct map_tracker {
 	uintptr_t end_addr;
 	unsigned region_id;
 	enum pmem_map_type type;
-#ifdef _WIN32
-	/* Windows-specific data */
-	HANDLE FileHandle;
-	HANDLE FileMappingHandle;
-	DWORD Access;
-	os_off_t Offset;
-	size_t FileLen;
-#endif
 };
 
 void util_mmap_init(void);
@@ -112,7 +99,7 @@ char *util_map_hint(size_t len, size_t req_align);
  * util_map_hint_align -- choose the desired mapping alignment
  *
  * The smallest supported alignment is 2 megabytes because of the object
- * alignment requirements. Changing this value to 4 kilobytes constitues a
+ * alignment requirements. Changing this value to 4 kilobytes constitutes a
  * layout change.
  *
  * Use 1GB page alignment only if the mapping length is at least
