@@ -149,36 +149,10 @@ enum pobj_arenas_assignment_type {
 	POBJ_ARENAS_ASSIGNMENT_GLOBAL,
 };
 
-#ifndef _WIN32
 /* EXPERIMENTAL */
 int pmemobj_ctl_get(PMEMobjpool *pop, const char *name, void *arg);
 int pmemobj_ctl_set(PMEMobjpool *pop, const char *name, void *arg);
 int pmemobj_ctl_exec(PMEMobjpool *pop, const char *name, void *arg);
-#else
-WIN_DEPR_ATTR
-int pmemobj_ctl_getU(PMEMobjpool *pop, const char *name, void *arg);
-WIN_DEPR_ATTR
-int pmemobj_ctl_getW(PMEMobjpool *pop, const wchar_t *name, void *arg);
-WIN_DEPR_ATTR
-int pmemobj_ctl_setU(PMEMobjpool *pop, const char *name, void *arg);
-WIN_DEPR_ATTR
-int pmemobj_ctl_setW(PMEMobjpool *pop, const wchar_t *name, void *arg);
-WIN_DEPR_ATTR
-int pmemobj_ctl_execU(PMEMobjpool *pop, const char *name, void *arg);
-WIN_DEPR_ATTR
-int pmemobj_ctl_execW(PMEMobjpool *pop, const wchar_t *name, void *arg);
-
-#ifndef PMDK_UTF8_API
-#define pmemobj_ctl_get pmemobj_ctl_getW
-#define pmemobj_ctl_set pmemobj_ctl_setW
-#define pmemobj_ctl_exec pmemobj_ctl_execW
-#else
-#define pmemobj_ctl_get pmemobj_ctl_getU
-#define pmemobj_ctl_set pmemobj_ctl_setU
-#define pmemobj_ctl_exec pmemobj_ctl_execU
-#endif
-
-#endif
 
 #ifdef __cplusplus
 }
