@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2014-2021, Intel Corporation */
+/* Copyright 2014-2024, Intel Corporation */
 
 #include <string.h>
 #include <sys/auxv.h>
@@ -7,6 +7,7 @@
 
 #include "auto_flush.h"
 #include "flush.h"
+#include "log_internal.h"
 #include "out.h"
 #include "pmem2_arch.h"
 
@@ -85,5 +86,5 @@ pmem2_arch_init(struct pmem2_arch_info *info)
 	else if (info->flush == flush_pop)
 		LOG(3, "Synchronize VA to pop for ARM");
 	else
-		FATAL("invalid deep flush function address");
+		CORE_LOG_FATAL("invalid deep flush function address");
 }
