@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2017-2022, Intel Corporation */
+/* Copyright 2017-2024, Intel Corporation */
 
 /*
  * badblocks_ndctl.c -- implementation of DIMMs API based on the ndctl library
@@ -16,7 +16,6 @@
 #include <sys/sysmacros.h>
 #include <fcntl.h>
 #include <ndctl/libndctl.h>
-#include <daxctl/libdaxctl.h>
 
 #include "libpmem2.h"
 #include "pmem2_utils.h"
@@ -25,9 +24,10 @@
 
 #include "file.h"
 #include "out.h"
-#include "badblocks.h"
+#include "bad_blocks.h"
 #include "set_badblocks.h"
 #include "extent.h"
+#include "badblocks.h"
 
 typedef int pmem2_badblock_next_type(
 		struct pmem2_badblock_context *bbctx,
@@ -115,13 +115,14 @@ badblocks_get_namespace_bounds(struct ndctl_region *region,
 	if (pfn) {
 		*ns_offset = ndctl_pfn_get_resource(pfn);
 		if (*ns_offset == ULLONG_MAX) {
-			ERR("(pfn) cannot read offset of the namespace");
+			ERR_WO_ERRNO(
+				"(pfn) cannot read offset of the namespace");
 			return PMEM2_E_CANNOT_READ_BOUNDS;
 		}
 
 		*ns_size = ndctl_pfn_get_size(pfn);
 		if (*ns_size == ULLONG_MAX) {
-			ERR("(pfn) cannot read size of the namespace");
+			ERR_WO_ERRNO("(pfn) cannot read size of the namespace");
 			return PMEM2_E_CANNOT_READ_BOUNDS;
 		}
 
@@ -130,13 +131,14 @@ badblocks_get_namespace_bounds(struct ndctl_region *region,
 	} else if (dax) {
 		*ns_offset = ndctl_dax_get_resource(dax);
 		if (*ns_offset == ULLONG_MAX) {
-			ERR("(dax) cannot read offset of the namespace");
+			ERR_WO_ERRNO(
+				"(dax) cannot read offset of the namespace");
 			return PMEM2_E_CANNOT_READ_BOUNDS;
 		}
 
 		*ns_size = ndctl_dax_get_size(dax);
 		if (*ns_size == ULLONG_MAX) {
-			ERR("(dax) cannot read size of the namespace");
+			ERR_WO_ERRNO("(dax) cannot read size of the namespace");
 			return PMEM2_E_CANNOT_READ_BOUNDS;
 		}
 
@@ -145,13 +147,15 @@ badblocks_get_namespace_bounds(struct ndctl_region *region,
 	} else { /* raw or btt */
 		*ns_offset = ndctl_namespace_get_resource(ndns);
 		if (*ns_offset == ULLONG_MAX) {
-			ERR("(raw/btt) cannot read offset of the namespace");
+			ERR_WO_ERRNO(
+				"(raw/btt) cannot read offset of the namespace");
 			return PMEM2_E_CANNOT_READ_BOUNDS;
 		}
 
 		*ns_size = ndctl_namespace_get_size(ndns);
 		if (*ns_size == ULLONG_MAX) {
-			ERR("(raw/btt) cannot read size of the namespace");
+			ERR_WO_ERRNO(
+				"(raw/btt) cannot read size of the namespace");
 			return PMEM2_E_CANNOT_READ_BOUNDS;
 		}
 
@@ -161,7 +165,7 @@ badblocks_get_namespace_bounds(struct ndctl_region *region,
 
 	unsigned long long region_offset = ndctl_region_get_resource(region);
 	if (region_offset == ULLONG_MAX) {
-		ERR("!cannot read offset of the region");
+		ERR_W_ERRNO("cannot read offset of the region");
 		return PMEM2_E_ERRNO;
 	}
 
@@ -188,14 +192,14 @@ badblocks_devdax_clear_one_badblock(struct ndctl_bus *bus,
 	struct ndctl_cmd *cmd_ars_cap = ndctl_bus_cmd_new_ars_cap(bus,
 							address, length);
 	if (cmd_ars_cap == NULL) {
-		ERR("ndctl_bus_cmd_new_ars_cap() failed (bus '%s')",
+		ERR_WO_ERRNO("ndctl_bus_cmd_new_ars_cap() failed (bus '%s')",
 			ndctl_bus_get_provider(bus));
 		return PMEM2_E_ERRNO;
 	}
 
 	ret = ndctl_cmd_submit(cmd_ars_cap);
 	if (ret) {
-		ERR("ndctl_cmd_submit() failed (bus '%s')",
+		ERR_WO_ERRNO("ndctl_cmd_submit() failed (bus '%s')",
 			ndctl_bus_get_provider(bus));
 		/* ndctl_cmd_submit() returns -errno */
 		goto out_ars_cap;
@@ -204,7 +208,7 @@ badblocks_devdax_clear_one_badblock(struct ndctl_bus *bus,
 	struct ndctl_range range;
 	ret = ndctl_cmd_ars_cap_get_range(cmd_ars_cap, &range);
 	if (ret) {
-		ERR("ndctl_cmd_ars_cap_get_range() failed");
+		ERR_WO_ERRNO("ndctl_cmd_ars_cap_get_range() failed");
 		/* ndctl_cmd_ars_cap_get_range() returns -errno */
 		goto out_ars_cap;
 	}
@@ -214,7 +218,7 @@ badblocks_devdax_clear_one_badblock(struct ndctl_bus *bus,
 
 	ret = ndctl_cmd_submit(cmd_clear_error);
 	if (ret) {
-		ERR("ndctl_cmd_submit() failed (bus '%s')",
+		ERR_WO_ERRNO("ndctl_cmd_submit() failed (bus '%s')",
 			ndctl_bus_get_provider(bus));
 		/* ndctl_cmd_submit() returns -errno */
 		goto out_clear_error;
@@ -227,7 +231,7 @@ badblocks_devdax_clear_one_badblock(struct ndctl_bus *bus,
 	ASSERT(cleared <= length);
 
 	if (cleared < length) {
-		ERR("failed to clear %llu out of %llu bad blocks",
+		ERR_WO_ERRNO("failed to clear %llu out of %llu bad blocks",
 			length - cleared, length);
 		errno = ENXIO; /* ndctl handles such error in this way */
 		ret = PMEM2_E_ERRNO;
@@ -256,7 +260,7 @@ pmem2_badblock_context_new(struct pmem2_badblock_context **bbctx,
 	ASSERTne(bbctx, NULL);
 
 	if (src->type == PMEM2_SOURCE_ANON) {
-		ERR("Anonymous source does not support bad blocks");
+		ERR_WO_ERRNO("Anonymous source does not support bad blocks");
 		return PMEM2_E_NOSUPP;
 	}
 
@@ -272,7 +276,7 @@ pmem2_badblock_context_new(struct pmem2_badblock_context **bbctx,
 
 	errno = ndctl_new(&ctx) * (-1);
 	if (errno) {
-		ERR("!ndctl_new");
+		ERR_W_ERRNO("ndctl_new");
 		return PMEM2_E_ERRNO;
 	}
 
@@ -280,7 +284,7 @@ pmem2_badblock_context_new(struct pmem2_badblock_context **bbctx,
 
 	ret = pmem2_region_namespace(ctx, src, &region, &ndns);
 	if (ret) {
-		LOG(1, "getting region and namespace failed");
+		CORE_LOG_ERROR("getting region and namespace failed");
 		goto exit_ndctl_unref;
 	}
 
@@ -310,7 +314,7 @@ pmem2_badblock_context_new(struct pmem2_badblock_context **bbctx,
 				region, ndns,
 				&ns_beg, &ns_size);
 		if (ret) {
-			LOG(1, "cannot read namespace's bounds");
+			CORE_LOG_ERROR("cannot read namespace's bounds");
 			goto error_free_all;
 		}
 
@@ -335,7 +339,7 @@ pmem2_badblock_context_new(struct pmem2_badblock_context **bbctx,
 		/* only regular files have extents */
 		ret = pmem2_extents_create_get(src->value.fd, &tbbctx->exts);
 		if (ret) {
-			LOG(1, "getting extents of fd %i failed",
+			CORE_LOG_ERROR("getting extents of fd %i failed",
 				src->value.fd);
 			goto error_free_all;
 		}
@@ -524,17 +528,13 @@ pmem2_badblock_next_region(struct pmem2_badblock_context *bbctx,
 }
 
 /*
- * pmem2_badblock_next -- get the next bad block
+ * pmem2_badblock_next_internal -- get the next bad block
  */
 int
-pmem2_badblock_next(struct pmem2_badblock_context *bbctx,
+pmem2_badblock_next_internal(struct pmem2_badblock_context *bbctx,
 			struct pmem2_badblock *bb)
 {
-	LOG(3, "bbctx %p bb %p", bbctx, bb);
-	PMEM2_ERR_CLR();
-
-	ASSERTne(bbctx, NULL);
-	ASSERTne(bb, NULL);
+	LOG(4, "bbctx %p bb %p", bbctx, bb);
 
 	struct pmem2_badblock bbn;
 	unsigned long long bb_beg;
@@ -547,8 +547,8 @@ pmem2_badblock_next(struct pmem2_badblock_context *bbctx,
 	int ret;
 
 	if (bbctx->rgn.region == NULL && bbctx->ndns == NULL) {
-		ERR("Cannot find any matching device, no bad blocks found");
-		return PMEM2_E_NO_BAD_BLOCK_FOUND;
+		/* Cannot find any matching device, no bad blocks found */
+		return ENODEV;
 	}
 
 	struct extents *exts = bbctx->exts;
@@ -687,13 +687,13 @@ pmem2_badblock_clear_fsdax(int fd, const struct pmem2_badblock *bb)
 
 	/* fallocate() takes offset as the off_t type */
 	if (bb->offset > (size_t)INT64_MAX) {
-		ERR("bad block's offset is greater than INT64_MAX");
+		ERR_WO_ERRNO("bad block's offset is greater than INT64_MAX");
 		return PMEM2_E_OFFSET_OUT_OF_RANGE;
 	}
 
 	/* fallocate() takes length as the off_t type */
 	if (bb->length > (size_t)INT64_MAX) {
-		ERR("bad block's length is greater than INT64_MAX");
+		ERR_WO_ERRNO("bad block's length is greater than INT64_MAX");
 		return PMEM2_E_LENGTH_OUT_OF_RANGE;
 	}
 
@@ -703,13 +703,13 @@ pmem2_badblock_clear_fsdax(int fd, const struct pmem2_badblock *bb)
 	/* deallocate bad blocks */
 	if (fallocate(fd, FALLOC_FL_PUNCH_HOLE | FALLOC_FL_KEEP_SIZE,
 			offset, length)) {
-		ERR("!fallocate");
+		ERR_W_ERRNO("fallocate");
 		return PMEM2_E_ERRNO;
 	}
 
 	/* allocate new blocks */
 	if (fallocate(fd, FALLOC_FL_KEEP_SIZE, offset, length)) {
-		ERR("!fallocate");
+		ERR_W_ERRNO("fallocate");
 		return PMEM2_E_ERRNO;
 	}
 
@@ -739,7 +739,7 @@ pmem2_badblock_clear_devdax(const struct pmem2_badblock_context *bbctx,
 				bb->offset + bbctx->rgn.ns_res,
 				bb->length);
 	if (ret) {
-		LOG(1,
+		CORE_LOG_ERROR(
 			"failed to clear a bad block: offset %zu length %zu (in 512B sectors)",
 			B2SEC(bb->offset),
 			B2SEC(bb->length));
