@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2020, Intel Corporation */
+/* Copyright 2024, Intel Corporation */
 
 /*
  * deep_flush.c -- pmem2_deep_flush implementation
@@ -27,14 +27,16 @@ pmem2_deep_flush(struct pmem2_map *map, void *ptr, size_t size)
 	uintptr_t flush_end = flush_addr + size;
 
 	if (flush_addr < map_addr || flush_end > map_end) {
-		ERR("requested deep flush rage ptr %p size %zu"
-			"exceeds map range %p", ptr, size, map);
+		ERR_WO_ERRNO(
+			"requested deep flush rage ptr %p size %zu exceeds map range %p",
+			ptr, size, map);
 		return PMEM2_E_DEEP_FLUSH_RANGE;
 	}
 
 	int ret = map->deep_flush_fn(map, ptr, size);
 	if (ret) {
-		LOG(1, "cannot perform deep flush operation for map %p", map);
+		CORE_LOG_ERROR(
+			"cannot perform deep flush operation for map %p", map);
 		return ret;
 	}
 
