@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2020, Intel Corporation */
+/* Copyright 2024, Intel Corporation */
 
 #include <errno.h>
 #include <ndctl/libndctl.h>
@@ -25,7 +25,7 @@ pmem2_source_numa_node(const struct pmem2_source *src, int *numa_node)
 	struct ndctl_region *region = NULL;
 
 	if (src->type == PMEM2_SOURCE_ANON) {
-		ERR("Anonymous sources are not bound to numa nodes.");
+		ERR_WO_ERRNO("Anonymous sources are not bound to numa nodes.");
 		return PMEM2_E_NOSUPP;
 	}
 
@@ -33,18 +33,18 @@ pmem2_source_numa_node(const struct pmem2_source *src, int *numa_node)
 
 	errno = ndctl_new(&ctx) * (-1);
 	if (errno) {
-		ERR("!ndctl_new");
+		ERR_W_ERRNO("ndctl_new");
 		return PMEM2_E_ERRNO;
 	}
 
 	int ret = pmem2_region_namespace(ctx, src, &region, NULL);
 	if (ret < 0) {
-		LOG(1, "getting region failed");
+		CORE_LOG_ERROR("getting region failed");
 		goto end;
 	}
 
 	if (region == NULL) {
-		ERR("unknown region");
+		ERR_WO_ERRNO("unknown region");
 		ret = PMEM2_E_DAX_REGION_NOT_FOUND;
 		goto end;
 	}
