@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: BSD-3-Clause */
-/* Copyright 2020-2021, Intel Corporation */
+/* Copyright 2020-2023, Intel Corporation */
 
 /*
  * vm_reservation.h -- internal definitions for virtual memory reservation
@@ -26,11 +26,4 @@ int vm_reservation_shrink_memory(struct pmem2_vm_reservation *rsv,
 
 size_t vm_reservation_get_map_alignment(size_t len, size_t min_align);
 
-#ifdef _WIN32
-int vm_reservation_merge_placeholders(struct pmem2_vm_reservation *rsv,
-		void *addr, size_t length);
-int vm_reservation_split_placeholders(struct pmem2_vm_reservation *rsv,
-		void *addr, size_t length);
-#endif
-
 #endif /* vm_reservation.h */
