@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2016-2021, Intel Corporation */
+/* Copyright 2016-2024, Intel Corporation */
 
 /*
  * memblock.c -- implementation of memory block
@@ -21,7 +21,7 @@
 #include "obj.h"
 #include "heap.h"
 #include "memblock.h"
-#include "out.h"
+#include "core_assert.h"
 #include "valgrind_internal.h"
 #include "alloc_class.h"
 
@@ -1103,7 +1103,7 @@ huge_vg_init(const struct memory_block *m, int objects,
 
 	if (objects && huge_get_state(m) == MEMBLOCK_ALLOCATED) {
 		if (cb(m, arg) != 0)
-			FATAL("failed to initialize valgrind state");
+			CORE_LOG_FATAL("failed to initialize valgrind state");
 	}
 }
 
@@ -1143,7 +1143,7 @@ run_vg_init(const struct memory_block *m, int objects,
 
 	if (objects) {
 		if (run_iterate_used(m, cb, arg) != 0)
-			FATAL("failed to initialize valgrind state");
+			CORE_LOG_FATAL("failed to initialize valgrind state");
 	}
 }
 
@@ -1463,7 +1463,8 @@ memblock_detect_type(struct palloc_heap *heap, const struct memory_block *m)
 			break;
 		default:
 			/* unreachable */
-			FATAL("possible zone chunks metadata corruption");
+			CORE_LOG_FATAL(
+				"possible zone chunks metadata corruption");
 	}
 	return ret;
 }
