@@ -1,34 +1,5 @@
-/*
- * Copyright 2017-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2017-2024, Intel Corporation */
 
 /*
  * stats.c -- implementation of statistics
@@ -36,6 +7,7 @@
 
 #include "obj.h"
 #include "stats.h"
+#include "core_assert.h"
 
 STATS_CTL_HANDLER(persistent, curr_allocated, heap_curr_allocated);
 
@@ -58,6 +30,9 @@ CTL_READ_HANDLER(enabled)(void *ctx,
 	enum ctl_query_source source, void *arg,
 	struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(source, indexes);
+
 	PMEMobjpool *pop = ctx;
 
 	enum pobj_stats_enabled *arg_out = arg;
@@ -75,6 +50,9 @@ stats_enabled_parser(const void *arg, void *dest, size_t dest_size)
 {
 	const char *vstr = arg;
 	enum pobj_stats_enabled *enabled = dest;
+#ifndef DEBUG
+	SUPPRESS_UNUSED(dest_size);
+#endif
 	ASSERTeq(dest_size, sizeof(enum pobj_stats_enabled));
 
 	int bool_out;
@@ -93,7 +71,7 @@ stats_enabled_parser(const void *arg, void *dest, size_t dest_size)
 	} else if (strcmp(vstr, "transient") == 0) {
 		*enabled = POBJ_STATS_ENABLED_TRANSIENT;
 	} else {
-		ERR("invalid enable type");
+		ERR_WO_ERRNO("invalid enable type");
 		errno = EINVAL;
 		return -1;
 	}
@@ -109,6 +87,9 @@ CTL_WRITE_HANDLER(enabled)(void *ctx,
 	enum ctl_query_source source, void *arg,
 	struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(source, indexes);
+
 	PMEMobjpool *pop = ctx;
 
 	pop->stats->enabled = *(enum pobj_stats_enabled *)arg;
@@ -140,7 +121,7 @@ stats_new(PMEMobjpool *pop)
 {
 	struct stats *s = Malloc(sizeof(*s));
 	if (s == NULL) {
-		ERR("!Malloc");
+		ERR_W_ERRNO("Malloc");
 		return NULL;
 	}
 
