@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2015-2020, Intel Corporation */
+/* Copyright 2015-2024, Intel Corporation */
 
 /*
  * tx.c -- transactions implementation
@@ -7,11 +7,12 @@
 
 #include <inttypes.h>
 #include <wchar.h>
+#include <stdarg.h>
 
 #include "queue.h"
 #include "ravl.h"
 #include "obj.h"
-#include "out.h"
+#include "core_assert.h"
 #include "pmalloc.h"
 #include "tx.h"
 #include "valgrind_internal.h"
@@ -158,13 +159,14 @@ obj_tx_fail_null(int errnum, uint64_t flags)
 /* ASSERT_IN_TX -- checks whether there's open transaction */
 #define ASSERT_IN_TX(tx) do {\
 	if ((tx)->stage == TX_STAGE_NONE)\
-		FATAL("%s called outside of transaction", __func__);\
+		CORE_LOG_FATAL("%s called outside of transaction", __func__);\
 } while (0)
 
 /* ASSERT_TX_STAGE_WORK -- checks whether current transaction stage is WORK */
 #define ASSERT_TX_STAGE_WORK(tx) do {\
 	if ((tx)->stage != TX_STAGE_WORK)\
-		FATAL("%s called in invalid stage %d", __func__, (tx)->stage);\
+		CORE_LOG_FATAL("%s called in invalid stage %d",\
+			__func__, (tx)->stage);\
 } while (0)
 
 /*
@@ -214,6 +216,9 @@ tx_action_remove(struct tx *tx)
 static int
 constructor_tx_alloc(void *ctx, void *ptr, size_t usable_size, void *arg)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(ctx);
+
 	LOG(5, NULL);
 
 	ASSERTne(ptr, NULL);
@@ -265,7 +270,7 @@ tx_remove_range(struct txr *tx_ranges, void *begin, void *end)
 			struct tx_range_data *txrn = Malloc(sizeof(*txrn));
 			if (txrn == NULL)
 				/* we can't do it any other way */
-				FATAL("!Malloc");
+				CORE_LOG_FATAL_W_ERRNO("Malloc");
 
 			txrn->begin = txr->begin;
 			txrn->end = begin;
@@ -277,7 +282,7 @@ tx_remove_range(struct txr *tx_ranges, void *begin, void *end)
 			struct tx_range_data *txrn = Malloc(sizeof(*txrn));
 			if (txrn == NULL)
 				/* we can't do it any other way */
-				FATAL("!Malloc");
+				CORE_LOG_FATAL_W_ERRNO("Malloc");
 
 			txrn->begin = end;
 			txrn->end = txr->end;
@@ -314,7 +319,7 @@ tx_restore_range(PMEMobjpool *pop, struct tx *tx, struct ulog_entry_buf *range)
 	txr = Malloc(sizeof(*txr));
 	if (txr == NULL) {
 		/* we can't do it any other way */
-		FATAL("!Malloc");
+		CORE_LOG_FATAL_W_ERRNO("Malloc");
 	}
 
 	uint64_t range_offset = ulog_entry_offset(&range->base);
@@ -359,6 +364,9 @@ static int
 tx_undo_entry_apply(struct ulog_entry_base *e, void *arg,
 	const struct pmem_ops *p_ops)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(arg);
+
 	struct ulog_entry_buf *eb;
 
 	switch (ulog_entry_type(e)) {
@@ -388,6 +396,7 @@ tx_abort_set(PMEMobjpool *pop, struct lane *lane)
 
 	ulog_foreach_entry((struct ulog *)&lane->layout->undo,
 		tx_undo_entry_apply, NULL, &pop->p_ops);
+	pmemops_drain(&pop->p_ops);
 	operation_finish(lane->undo, ULOG_INC_FIRST_GEN_NUM);
 }
 
@@ -488,7 +497,7 @@ add_to_tx_and_lock(struct tx *tx, enum pobj_tx_param type, void *lock)
 			retval = pmemobj_mutex_lock(tx->pop,
 				txl->lock.mutex);
 			if (retval) {
-				ERR("!pmemobj_mutex_lock");
+				ERR_W_ERRNO("pmemobj_mutex_lock");
 				goto err;
 			}
 			break;
@@ -497,12 +506,12 @@ add_to_tx_and_lock(struct tx *tx, enum pobj_tx_param type, void *lock)
 			retval = pmemobj_rwlock_wrlock(tx->pop,
 				txl->lock.rwlock);
 			if (retval) {
-				ERR("!pmemobj_rwlock_wrlock");
+				ERR_W_ERRNO("pmemobj_rwlock_wrlock");
 				goto err;
 			}
 			break;
 		default:
-			ERR("Unrecognized lock type");
+			ERR_WO_ERRNO("Unrecognized lock type");
 			ASSERT(0);
 			break;
 	}
@@ -539,7 +548,7 @@ release_and_free_tx_locks(struct tx *tx)
 					tx_lock->lock.rwlock);
 				break;
 			default:
-				ERR("Unrecognized lock type");
+				ERR_WO_ERRNO("Unrecognized lock type");
 				ASSERT(0);
 				break;
 		}
@@ -555,12 +564,15 @@ static int
 tx_lane_ranges_insert_def(PMEMobjpool *pop, struct tx *tx,
 	const struct tx_range_def *rdef)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(pop);
+
 	LOG(3, "rdef->offset %"PRIu64" rdef->size %"PRIu64,
 		rdef->offset, rdef->size);
 
 	int ret = ravl_emplace_copy(tx->ranges, rdef);
 	if (ret && errno == EEXIST)
-		FATAL("invalid state of ranges tree");
+		CORE_LOG_FATAL("invalid state of ranges tree");
 	return ret;
 }
 
@@ -574,7 +586,7 @@ tx_alloc_common(struct tx *tx, size_t size, type_num_t type_num,
 	LOG(3, NULL);
 
 	if (size > PMEMOBJ_MAX_ALLOC_SIZE) {
-		ERR("requested size too large");
+		ERR_WO_ERRNO("requested size too large");
 		return obj_tx_fail_null(ENOMEM, args.flags);
 	}
 
@@ -603,7 +615,7 @@ tx_alloc_common(struct tx *tx, size_t size, type_num_t type_num,
 
 err_oom:
 	tx_action_remove(tx);
-	ERR("out of memory");
+	ERR_WO_ERRNO("out of memory");
 	return obj_tx_fail_null(ENOMEM, args.flags);
 }
 
@@ -619,7 +631,7 @@ tx_realloc_common(struct tx *tx, PMEMoid oid, size_t size, uint64_t type_num,
 	LOG(3, NULL);
 
 	if (size > PMEMOBJ_MAX_ALLOC_SIZE) {
-		ERR("requested size too large");
+		ERR_WO_ERRNO("requested size too large");
 		return obj_tx_fail_null(ENOMEM, flags);
 	}
 
@@ -633,7 +645,7 @@ tx_realloc_common(struct tx *tx, PMEMoid oid, size_t size, uint64_t type_num,
 	/* if size is 0 just free */
 	if (size == 0) {
 		if (pmemobj_tx_free(oid)) {
-			ERR("pmemobj_tx_free failed");
+			ERR_WO_ERRNO("pmemobj_tx_free failed");
 			return oid;
 		} else {
 			return OID_NULL;
@@ -651,7 +663,7 @@ tx_realloc_common(struct tx *tx, PMEMoid oid, size_t size, uint64_t type_num,
 
 	if (!OBJ_OID_IS_NULL(new_obj)) {
 		if (pmemobj_tx_free(oid)) {
-			ERR("pmemobj_tx_free failed");
+			ERR_WO_ERRNO("pmemobj_tx_free failed");
 			VEC_POP_BACK(&tx->actions);
 			return OID_NULL;
 		}
@@ -668,7 +680,7 @@ tx_construct_user_buffer(struct tx *tx, void *addr, size_t size,
 		enum pobj_log_type type, int outer_tx, uint64_t flags)
 {
 	if (tx->pop != pmemobj_pool_by_ptr(addr)) {
-		ERR("Buffer from a different pool");
+		ERR_WO_ERRNO("Buffer from a different pool");
 		goto err;
 	}
 
@@ -725,7 +737,7 @@ pmemobj_tx_begin(PMEMobjpool *pop, jmp_buf env, ...)
 	if (tx->stage == TX_STAGE_WORK) {
 		ASSERTne(tx->lane, NULL);
 		if (tx->pop != pop) {
-			ERR("nested transaction for different pool");
+			ERR_WO_ERRNO("nested transaction for different pool");
 			return obj_tx_fail_err(EINVAL, 0);
 		}
 
@@ -755,13 +767,14 @@ pmemobj_tx_begin(PMEMobjpool *pop, jmp_buf env, ...)
 
 		tx->user_data = NULL;
 	} else {
-		FATAL("Invalid stage %d to begin new transaction", tx->stage);
+		CORE_LOG_FATAL("Invalid stage %d to begin new transaction",
+			tx->stage);
 	}
 
 	struct tx_data *txd = Malloc(sizeof(*txd));
 	if (txd == NULL) {
 		err = errno;
-		ERR("!Malloc");
+		ERR_W_ERRNO("Malloc");
 		goto err_abort;
 	}
 
@@ -792,8 +805,8 @@ pmemobj_tx_begin(PMEMobjpool *pop, jmp_buf env, ...)
 			if (tx->stage_callback &&
 					(tx->stage_callback != cb ||
 					tx->stage_callback_arg != arg)) {
-				FATAL("transaction callback is already set, "
-					"old %p new %p old_arg %p new_arg %p",
+				CORE_LOG_FATAL(
+					"transaction callback is already set, old %p new %p old_arg %p new_arg %p",
 					tx->stage_callback, cb,
 					tx->stage_callback_arg, arg);
 			}
@@ -850,7 +863,7 @@ pmemobj_tx_xlock(enum pobj_tx_param type, void *lockp, uint64_t flags)
 	flags |= tx_abort_on_failure_flag(tx);
 
 	if (flags & ~POBJ_XLOCK_VALID_FLAGS) {
-		ERR("unknown flags 0x%" PRIx64,
+		ERR_WO_ERRNO("unknown flags 0x%" PRIx64,
 				flags & ~POBJ_XLOCK_VALID_FLAGS);
 		return obj_tx_fail_err(EINVAL, flags);
 	}
@@ -928,9 +941,8 @@ obj_tx_abort(int errnum, int user)
 	}
 
 	tx->last_errnum = errnum;
-	errno = errnum;
 	if (user)
-		ERR("!explicit transaction abort");
+		CORE_LOG_HARK("Explicit transaction abort: %d", errnum);
 
 	/* ONABORT */
 	obj_tx_callback(tx);
@@ -1034,10 +1046,12 @@ pmemobj_tx_end(void)
 	struct tx *tx = get_tx();
 
 	if (tx->stage == TX_STAGE_WORK)
-		FATAL("pmemobj_tx_end called without pmemobj_tx_commit");
+		CORE_LOG_FATAL(
+			"pmemobj_tx_end called without pmemobj_tx_commit");
 
 	if (tx->pop == NULL)
-		FATAL("pmemobj_tx_end called without pmemobj_tx_begin");
+		CORE_LOG_FATAL(
+			"pmemobj_tx_end called without pmemobj_tx_begin");
 
 	if (tx->stage_callback &&
 			(tx->stage == TX_STAGE_ONCOMMIT ||
@@ -1052,6 +1066,7 @@ pmemobj_tx_end(void)
 	Free(txd);
 
 	VALGRIND_END_TX;
+	int ret = tx->last_errnum;
 
 	if (PMDK_SLIST_EMPTY(&tx->tx_entries)) {
 		ASSERTeq(tx->lane, NULL);
@@ -1070,6 +1085,7 @@ pmemobj_tx_end(void)
 			tx->stage_callback_arg = NULL;
 
 			cb(tx->pop, TX_STAGE_NONE, arg);
+			/* tx should not be accessed after this callback */
 		}
 	} else {
 		/* resume the next transaction */
@@ -1080,7 +1096,7 @@ pmemobj_tx_end(void)
 			obj_tx_abort(tx->last_errnum, 0);
 	}
 
-	return tx->last_errnum;
+	return ret;
 }
 
 /*
@@ -1122,6 +1138,8 @@ pmemobj_tx_process(void)
 static void
 vg_verify_initialized(PMEMobjpool *pop, const struct tx_range_def *def)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(pop, def);
 #if VG_MEMCHECK_ENABLED
 	if (!On_memcheck)
 		return;
@@ -1215,14 +1233,14 @@ pmemobj_tx_add_common(struct tx *tx, struct tx_range_def *args)
 	LOG(15, NULL);
 
 	if (args->size > PMEMOBJ_MAX_ALLOC_SIZE) {
-		ERR("snapshot size too large");
+		ERR_WO_ERRNO("snapshot size too large");
 		return obj_tx_fail_err(EINVAL, args->flags);
 	}
 
 	if (args->offset < tx->pop->heap_offset ||
 		(args->offset + args->size) >
 		(tx->pop->heap_offset + tx->pop->heap_size)) {
-		ERR("object outside of heap");
+		ERR_WO_ERRNO("object outside of heap");
 		return obj_tx_fail_err(EINVAL, args->flags);
 	}
 
@@ -1362,7 +1380,7 @@ pmemobj_tx_add_common(struct tx *tx, struct tx_range_def *args)
 	}
 
 	if (ret != 0) {
-		ERR("out of memory");
+		ERR_WO_ERRNO("out of memory");
 		return obj_tx_fail_err(ENOMEM, args->flags);
 	}
 
@@ -1389,7 +1407,7 @@ pmemobj_tx_add_range_direct(const void *ptr, size_t size)
 	uint64_t flags = tx_abort_on_failure_flag(tx);
 
 	if (!OBJ_PTR_FROM_POOL(tx->pop, ptr)) {
-		ERR("object outside of pool");
+		ERR_WO_ERRNO("object outside of pool");
 		ret = obj_tx_fail_err(EINVAL, flags);
 		PMEMOBJ_API_END();
 		return ret;
@@ -1427,7 +1445,7 @@ pmemobj_tx_xadd_range_direct(const void *ptr, size_t size, uint64_t flags)
 	flags |= tx_abort_on_failure_flag(tx);
 
 	if (flags & ~POBJ_XADD_VALID_FLAGS) {
-		ERR("unknown flags 0x%" PRIx64, flags
+		ERR_WO_ERRNO("unknown flags 0x%" PRIx64, flags
 			& ~POBJ_XADD_VALID_FLAGS);
 		ret = obj_tx_fail_err(EINVAL, flags);
 		PMEMOBJ_API_END();
@@ -1435,7 +1453,7 @@ pmemobj_tx_xadd_range_direct(const void *ptr, size_t size, uint64_t flags)
 	}
 
 	if (!OBJ_PTR_FROM_POOL(tx->pop, ptr)) {
-		ERR("object outside of pool");
+		ERR_WO_ERRNO("object outside of pool");
 		ret = obj_tx_fail_err(EINVAL, flags);
 		PMEMOBJ_API_END();
 		return ret;
@@ -1472,7 +1490,7 @@ pmemobj_tx_add_range(PMEMoid oid, uint64_t hoff, size_t size)
 	uint64_t flags = tx_abort_on_failure_flag(tx);
 
 	if (oid.pool_uuid_lo != tx->pop->uuid_lo) {
-		ERR("invalid pool uuid");
+		ERR_WO_ERRNO("invalid pool uuid");
 		ret = obj_tx_fail_err(EINVAL, flags);
 		PMEMOBJ_API_END();
 		return ret;
@@ -1510,7 +1528,7 @@ pmemobj_tx_xadd_range(PMEMoid oid, uint64_t hoff, size_t size, uint64_t flags)
 	flags |= tx_abort_on_failure_flag(tx);
 
 	if (flags & ~POBJ_XADD_VALID_FLAGS) {
-		ERR("unknown flags 0x%" PRIx64, flags
+		ERR_WO_ERRNO("unknown flags 0x%" PRIx64, flags
 			& ~POBJ_XADD_VALID_FLAGS);
 		ret = obj_tx_fail_err(EINVAL, flags);
 		PMEMOBJ_API_END();
@@ -1518,7 +1536,7 @@ pmemobj_tx_xadd_range(PMEMoid oid, uint64_t hoff, size_t size, uint64_t flags)
 	}
 
 	if (oid.pool_uuid_lo != tx->pop->uuid_lo) {
-		ERR("invalid pool uuid");
+		ERR_WO_ERRNO("invalid pool uuid");
 		ret = obj_tx_fail_err(EINVAL, flags);
 		PMEMOBJ_API_END();
 		return ret;
@@ -1555,7 +1573,7 @@ pmemobj_tx_alloc(size_t size, uint64_t type_num)
 
 	PMEMoid oid;
 	if (size == 0) {
-		ERR("allocation with size 0");
+		ERR_WO_ERRNO("allocation with size 0");
 		oid = obj_tx_fail_null(EINVAL, flags);
 		PMEMOBJ_API_END();
 		return oid;
@@ -1586,7 +1604,7 @@ pmemobj_tx_zalloc(size_t size, uint64_t type_num)
 	PMEMOBJ_API_START();
 	PMEMoid oid;
 	if (size == 0) {
-		ERR("allocation with size 0");
+		ERR_WO_ERRNO("allocation with size 0");
 		oid = obj_tx_fail_null(EINVAL, flags);
 		PMEMOBJ_API_END();
 		return oid;
@@ -1617,14 +1635,14 @@ pmemobj_tx_xalloc(size_t size, uint64_t type_num, uint64_t flags)
 
 	PMEMoid oid;
 	if (size == 0) {
-		ERR("allocation with size 0");
+		ERR_WO_ERRNO("allocation with size 0");
 		oid = obj_tx_fail_null(EINVAL, flags);
 		PMEMOBJ_API_END();
 		return oid;
 	}
 
 	if (flags & ~POBJ_TX_XALLOC_VALID_FLAGS) {
-		ERR("unknown flags 0x%" PRIx64, flags
+		ERR_WO_ERRNO("unknown flags 0x%" PRIx64, flags
 			& ~(POBJ_TX_XALLOC_VALID_FLAGS));
 		oid = obj_tx_fail_null(EINVAL, flags);
 		PMEMOBJ_API_END();
@@ -1693,7 +1711,7 @@ pmemobj_tx_xstrdup(const char *s, uint64_t type_num, uint64_t flags)
 	flags |= tx_abort_on_failure_flag(tx);
 
 	if (flags & ~POBJ_TX_XALLOC_VALID_FLAGS) {
-		ERR("unknown flags 0x%" PRIx64,
+		ERR_WO_ERRNO("unknown flags 0x%" PRIx64,
 				flags & ~POBJ_TX_XALLOC_VALID_FLAGS);
 		return obj_tx_fail_null(EINVAL, flags);
 	}
@@ -1701,7 +1719,7 @@ pmemobj_tx_xstrdup(const char *s, uint64_t type_num, uint64_t flags)
 	PMEMOBJ_API_START();
 	PMEMoid oid;
 	if (NULL == s) {
-		ERR("cannot duplicate NULL string");
+		ERR_WO_ERRNO("cannot duplicate NULL string");
 		oid = obj_tx_fail_null(EINVAL, flags);
 		PMEMOBJ_API_END();
 		return oid;
@@ -1751,7 +1769,7 @@ pmemobj_tx_xwcsdup(const wchar_t *s, uint64_t type_num, uint64_t flags)
 	flags |= tx_abort_on_failure_flag(tx);
 
 	if (flags & ~POBJ_TX_XALLOC_VALID_FLAGS) {
-		ERR("unknown flags 0x%" PRIx64,
+		ERR_WO_ERRNO("unknown flags 0x%" PRIx64,
 				flags & ~POBJ_TX_XALLOC_VALID_FLAGS);
 		return obj_tx_fail_null(EINVAL, flags);
 	}
@@ -1759,7 +1777,7 @@ pmemobj_tx_xwcsdup(const wchar_t *s, uint64_t type_num, uint64_t flags)
 	PMEMOBJ_API_START();
 	PMEMoid oid;
 	if (NULL == s) {
-		ERR("cannot duplicate NULL string");
+		ERR_WO_ERRNO("cannot duplicate NULL string");
 		oid = obj_tx_fail_null(EINVAL, flags);
 		PMEMOBJ_API_END();
 		return oid;
@@ -1810,7 +1828,7 @@ pmemobj_tx_xfree(PMEMoid oid, uint64_t flags)
 	flags |= tx_abort_on_failure_flag(tx);
 
 	if (flags & ~POBJ_XFREE_VALID_FLAGS) {
-		ERR("unknown flags 0x%" PRIx64,
+		ERR_WO_ERRNO("unknown flags 0x%" PRIx64,
 				flags & ~POBJ_XFREE_VALID_FLAGS);
 		return obj_tx_fail_err(EINVAL, flags);
 	}
@@ -1821,7 +1839,7 @@ pmemobj_tx_xfree(PMEMoid oid, uint64_t flags)
 	PMEMobjpool *pop = tx->pop;
 
 	if (pop->uuid_lo != oid.pool_uuid_lo) {
-		ERR("invalid pool uuid");
+		ERR_WO_ERRNO("invalid pool uuid");
 		return obj_tx_fail_err(EINVAL, flags);
 	}
 
@@ -1893,7 +1911,7 @@ pmemobj_tx_xpublish(struct pobj_action *actv, size_t actvcnt, uint64_t flags)
 	flags |= tx_abort_on_failure_flag(tx);
 
 	if (flags & ~POBJ_XPUBLISH_VALID_FLAGS) {
-		ERR("unknown flags 0x%" PRIx64,
+		ERR_WO_ERRNO("unknown flags 0x%" PRIx64,
 				flags & ~POBJ_XPUBLISH_VALID_FLAGS);
 		return obj_tx_fail_err(EINVAL, flags);
 	}
@@ -1938,7 +1956,7 @@ pmemobj_tx_xlog_append_buffer(enum pobj_log_type type, void *addr, size_t size,
 	flags |= tx_abort_on_failure_flag(tx);
 
 	if (flags & ~POBJ_XLOG_APPEND_BUFFER_VALID_FLAGS) {
-		ERR("unknown flags 0x%" PRIx64,
+		ERR_WO_ERRNO("unknown flags 0x%" PRIx64,
 				flags & ~POBJ_XLOG_APPEND_BUFFER_VALID_FLAGS);
 		return obj_tx_fail_err(EINVAL, flags);
 	}
@@ -2159,6 +2177,9 @@ static int
 CTL_READ_HANDLER(size)(void *ctx,
 	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(source, indexes);
+
 	PMEMobjpool *pop = ctx;
 
 	ssize_t *arg_out = arg;
@@ -2175,13 +2196,17 @@ static int
 CTL_WRITE_HANDLER(size)(void *ctx,
 	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(source, indexes);
+
 	PMEMobjpool *pop = ctx;
 
-	ssize_t arg_in = *(int *)arg;
+	ssize_t arg_in = *(long long *)arg;
 
 	if (arg_in < 0 || arg_in > (ssize_t)PMEMOBJ_MAX_ALLOC_SIZE) {
 		errno = EINVAL;
-		ERR("invalid cache size, must be between 0 and max alloc size");
+		ERR_WO_ERRNO(
+			"invalid cache size, must be between 0 and max alloc size");
 		return -1;
 	}
 
@@ -2201,9 +2226,12 @@ static int
 CTL_READ_HANDLER(threshold)(void *ctx,
 	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
 {
-	LOG(1, "tx.cache.threshold parameter is deprecated");
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(ctx, source, arg, indexes);
 
-	return 0;
+	ERR_WO_ERRNO("tx.cache.threshold parameter is deprecated");
+
+	return -1;
 }
 
 /*
@@ -2213,9 +2241,12 @@ static int
 CTL_WRITE_HANDLER(threshold)(void *ctx,
 	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
 {
-	LOG(1, "tx.cache.threshold parameter is deprecated");
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(ctx, source, arg, indexes);
 
-	return 0;
+	ERR_WO_ERRNO("tx.cache.threshold parameter is deprecated");
+
+	return -1;
 }
 
 static const struct ctl_argument CTL_ARG(threshold) = CTL_ARG_LONG_LONG;
@@ -2235,6 +2266,9 @@ static int
 CTL_READ_HANDLER(skip_expensive_checks)(void *ctx,
 	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(source, indexes);
+
 	PMEMobjpool *pop = ctx;
 
 	int *arg_out = arg;
@@ -2252,6 +2286,9 @@ static int
 CTL_WRITE_HANDLER(skip_expensive_checks)(void *ctx,
 	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(source, indexes);
+
 	PMEMobjpool *pop = ctx;
 
 	int arg_in = *(int *)arg;
@@ -2271,6 +2308,9 @@ static int
 CTL_READ_HANDLER(verify_user_buffers)(void *ctx,
 	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(source, indexes);
+
 	PMEMobjpool *pop = ctx;
 
 	int *arg_out = arg;
@@ -2288,6 +2328,9 @@ static int
 CTL_WRITE_HANDLER(verify_user_buffers)(void *ctx,
 	enum ctl_query_source source, void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(source, indexes);
+
 	PMEMobjpool *pop = ctx;
 
 	int arg_in = *(int *)arg;
@@ -2313,6 +2356,9 @@ static int
 CTL_READ_HANDLER(queue_depth)(void *ctx, enum ctl_query_source source,
 	void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(ctx, source, arg, indexes);
+
 	return 0;
 }
 
@@ -2323,6 +2369,9 @@ static int
 CTL_WRITE_HANDLER(queue_depth)(void *ctx, enum ctl_query_source source,
 	void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(ctx, source, arg, indexes);
+
 	return 0;
 }
 
@@ -2335,6 +2384,9 @@ static int
 CTL_READ_HANDLER(worker)(void *ctx, enum ctl_query_source source,
 	void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(ctx, source, arg, indexes);
+
 	return 0;
 }
 
@@ -2345,6 +2397,9 @@ static int
 CTL_READ_HANDLER(stop)(void *ctx, enum ctl_query_source source,
 	void *arg, struct ctl_indexes *indexes)
 {
+	/* suppress unused-parameter errors */
+	SUPPRESS_UNUSED(ctx, source, arg, indexes);
+
 	return 0;
 }
 
