@@ -1,5 +1,5 @@
-// SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2016-2018, Intel Corporation */
+/* SPDX-License-Identifier: BSD-3-Clause */
+/* Copyright 2016-2023, Intel Corporation */
 
 /*
  * check.h -- internal definitions for logic performing check
@@ -19,10 +19,6 @@ void check_fini(PMEMpoolcheck *ppc);
 int check_is_end(struct check_data *data);
 struct pmempool_check_status *check_status_get(struct check_status *status);
 
-#ifdef _WIN32
-void convert_status_cache(PMEMpoolcheck *ppc, char *buf, size_t size);
-#endif
-
 #ifdef __cplusplus
 }
 #endif
