@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2016-2022, Intel Corporation */
+/* Copyright 2016-2024, Intel Corporation */
 
 /*
  * check_util.c -- check utility functions
@@ -7,6 +7,7 @@
 
 #include <stdio.h>
 #include <stdint.h>
+#include <stdarg.h>
 
 #include "out.h"
 #include "libpmempool.h"
@@ -20,7 +21,9 @@
 #define MSG_SEPARATOR	'|'
 
 /* error part of message must have '.' at the end */
+#ifdef DEBUG /* variables required for ASSERTs below */
 #define MSG_PLACE_OF_SEPARATION	'.'
+#endif
 #define MAX_MSG_STR_SIZE 8192
 
 #define CHECK_ANSWER_YES	"yes"
@@ -72,7 +75,7 @@ check_data_alloc(void)
 
 	struct check_data *data = calloc(1, sizeof(*data));
 	if (data == NULL) {
-		ERR("!calloc");
+		ERR_W_ERRNO("calloc");
 		return NULL;
 	}
 
@@ -181,11 +184,11 @@ status_alloc(void)
 {
 	struct check_status *status = malloc(sizeof(*status));
 	if (!status)
-		FATAL("!malloc");
+		CORE_LOG_FATAL_W_ERRNO("malloc");
 	status->msg = malloc(sizeof(char) * MAX_MSG_STR_SIZE);
 	if (!status->msg) {
 		free(status);
-		FATAL("!malloc");
+		CORE_LOG_FATAL_W_ERRNO("malloc");
 	}
 	status->status.str.msg = status->msg;
 	status->answer = PMEMPOOL_CHECK_ANSWER_EMPTY;
@@ -199,11 +202,6 @@ status_alloc(void)
 static void
 status_release(struct check_status *status)
 {
-#ifdef _WIN32
-	/* dealloc duplicate string after conversion */
-	if (status->status.str.msg != status->msg)
-		free((void *)status->status.str.msg);
-#endif
 	free(status->msg);
 	free(status);
 }
@@ -267,7 +265,7 @@ status_push(PMEMpoolcheck *ppc, struct check_status *st, uint32_t question)
 	if (CHECK_IS_NOT(ppc, REPAIR)) {
 		/* error status */
 		if (status_msg_info_only(st->msg)) {
-			ERR("no error message for the user");
+			ERR_WO_ERRNO("no error message for the user");
 			st->msg[0] = '\0';
 		}
 		st->status.type = PMEMPOOL_CHECK_MSG_TYPE_ERROR;
@@ -334,7 +332,7 @@ check_status_create(PMEMpoolcheck *ppc, enum pmempool_check_msg_type type,
 		int ret = util_snprintf(st->msg + p,
 				MAX_MSG_STR_SIZE - (size_t)p, ": %s", buff);
 		if (ret < 0) {
-			ERR("!snprintf");
+			ERR_W_ERRNO("snprintf");
 			status_release(st);
 			return -1;
 		}
@@ -408,33 +406,6 @@ check_pop_error(struct check_data *data)
 	return NULL;
 }
 
-#ifdef _WIN32
-void
-cache_to_utf8(struct check_data *data, char *buf, size_t size)
-{
-	if (data->check_status_cache == NULL)
-		return;
-
-	struct check_status *status = data->check_status_cache;
-
-	/* if it was a question, convert it and the answer to utf8 */
-	if (status->status.type == PMEMPOOL_CHECK_MSG_TYPE_QUESTION) {
-		struct pmempool_check_statusW *wstatus =
-			(struct pmempool_check_statusW *)&status->status;
-		wchar_t *wstring = (wchar_t *)wstatus->str.msg;
-		status->status.str.msg = util_toUTF8(wstring);
-		if (status->status.str.msg == NULL)
-			FATAL("!malloc");
-		util_free_UTF16(wstring);
-
-		if (util_toUTF8_buff(wstatus->str.answer, buf, size) != 0)
-			FATAL("Invalid answer conversion %s",
-				out_get_errormsg());
-		status->status.str.answer = buf;
-	}
-}
-#endif
-
 /*
  * check_clear_status_cache -- release check_status from cache
  */
@@ -635,7 +606,7 @@ check_get_time_str(time_t time)
 	else {
 		int ret = util_snprintf(str_buff, STR_MAX, "unknown");
 		if (ret < 0) {
-			ERR("!snprintf");
+			ERR_W_ERRNO("snprintf");
 			return "";
 		}
 	}
@@ -652,18 +623,8 @@ check_get_uuid_str(uuid_t uuid)
 
 	int ret = util_uuid_to_string(uuid, uuid_str);
 	if (ret != 0) {
-		ERR("failed to convert uuid to string");
+		ERR_WO_ERRNO("failed to convert uuid to string");
 		return "";
 	}
 	return uuid_str;
 }
-
-/*
- * pmempool_check_insert_arena -- insert arena to list
- */
-void
-check_insert_arena(PMEMpoolcheck *ppc, struct arena *arenap)
-{
-	PMDK_TAILQ_INSERT_TAIL(&ppc->pool->arenas, arenap, next);
-	ppc->pool->narenas++;
-}
