@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2016-2022, Intel Corporation */
+/* Copyright 2016-2024, Intel Corporation */
 
 /*
  * transform.c -- a module for poolset transforming
@@ -55,12 +55,13 @@ check_if_part_used_once(struct pool_set *set, unsigned repn, unsigned partn)
 	struct pool_replica *rep = REP(set, repn);
 	char *path = util_part_realpath(PART(rep, partn)->path);
 	if (path == NULL) {
-		LOG(1, "cannot get absolute path for %s, replica %u, part %u",
-				PART(rep, partn)->path, repn, partn);
+		CORE_LOG_WARNING(
+			"cannot get absolute path for %s, replica %u, part %u",
+			PART(rep, partn)->path, repn, partn);
 		errno = 0;
 		path = strdup(PART(rep, partn)->path);
 		if (path == NULL) {
-			ERR("!strdup");
+			ERR_W_ERRNO("strdup");
 			return -1;
 		}
 	}
@@ -74,30 +75,31 @@ check_if_part_used_once(struct pool_set *set, unsigned repn, unsigned partn)
 			char *pathp = util_part_realpath(PART(repr, p)->path);
 			if (pathp == NULL) {
 				if (errno != ENOENT) {
-					ERR("realpath failed for %s, errno %d",
+					ERR_WO_ERRNO(
+						"realpath failed for %s, errno %d",
 						PART(repr, p)->path, errno);
 					ret = -1;
 					goto out;
 				}
-				LOG(1, "cannot get absolute path for %s,"
-						" replica %u, part %u",
-						PART(rep, partn)->path, repn,
-						partn);
+				CORE_LOG_WARNING(
+					"cannot get absolute path for %s, replica %u, part %u",
+					PART(rep, partn)->path, repn, partn);
 				pathp = strdup(PART(repr, p)->path);
 				errno = 0;
 			}
 			int result = util_compare_file_inodes(path, pathp);
 			if (result == 0) {
 				/* same file used multiple times */
-				ERR("some part file's path is"
-						" used multiple times");
+				ERR_WO_ERRNO(
+					"some part file's path is used multiple times");
 				ret = -1;
 				errno = EINVAL;
 				free(pathp);
 				goto out;
 			} else if (result < 0) {
-				ERR("comparing file inodes failed for %s and"
-						" %s", path, pathp);
+				ERR_WO_ERRNO(
+					"comparing file inodes failed for %s and %s",
+					path, pathp);
 				ret = -1;
 				free(pathp);
 				goto out;
@@ -140,7 +142,8 @@ validate_args(struct pool_set *set_in, struct pool_set *set_out)
 	LOG(3, "set_in %p, set_out %p", set_in, set_out);
 
 	if (set_in->directory_based) {
-		ERR("transform of directory poolsets is not supported");
+		ERR_WO_ERRNO(
+			"transform of directory poolsets is not supported");
 		errno = EINVAL;
 		return -1;
 	}
@@ -150,7 +153,7 @@ validate_args(struct pool_set *set_in, struct pool_set *set_out)
 	 * (now replication works only for pmemobj pools)
 	 */
 	if (replica_check_part_sizes(set_out, PMEMOBJ_MIN_POOL)) {
-		ERR("part sizes check failed");
+		ERR_WO_ERRNO("part sizes check failed");
 		return -1;
 	}
 
@@ -168,12 +171,12 @@ validate_args(struct pool_set *set_in, struct pool_set *set_out)
 	 */
 	ssize_t master_pool_size = replica_get_pool_size(set_in, 0);
 	if (master_pool_size < 0) {
-		ERR("getting pool size from master replica failed");
+		ERR_WO_ERRNO("getting pool size from master replica failed");
 		return -1;
 	}
 
 	if (set_out->poolsize < (size_t)master_pool_size) {
-		ERR("target poolset is too small");
+		ERR_WO_ERRNO("target poolset is too small");
 		errno = EINVAL;
 		return -1;
 	}
@@ -194,7 +197,7 @@ create_poolset_compare_status(struct pool_set *set,
 	set_s = Zalloc(sizeof(struct poolset_compare_status)
 				+ set->nreplicas * sizeof(unsigned));
 	if (set_s == NULL) {
-		ERR("!Zalloc for poolset status");
+		ERR_W_ERRNO("Zalloc for poolset status");
 		return -1;
 	}
 	for (unsigned r = 0; r < set->nreplicas; ++r)
@@ -256,7 +259,8 @@ check_compare_poolsets_status(struct pool_set *set_in,
 		struct pool_replica *rep_in = REP(set_in, ri);
 		for (unsigned ro = 0; ro < set_out->nreplicas; ++ro) {
 			struct pool_replica *rep_out = REP(set_out, ro);
-			LOG(1, "comparing rep_in %u with rep_out %u", ri, ro);
+			CORE_LOG_DEBUG("comparing rep_in %u with rep_out %u",
+				ri, ro);
 			/* skip different replicas */
 			if (compare_replicas(rep_in, rep_out))
 				continue;
@@ -265,8 +269,8 @@ check_compare_poolsets_status(struct pool_set *set_in,
 					set_out_s->replica[ro]
 						!= UNDEF_REPLICA) {
 				/* there are more than one counterparts */
-				ERR("there are more then one corresponding"
-						" replicas; cannot transform");
+				ERR_WO_ERRNO(
+					"there are more then one corresponding replicas; cannot transform");
 				errno = EINVAL;
 				return -1;
 			}
@@ -296,8 +300,8 @@ check_compare_poolsets_options(struct pool_set *set_in,
 	if ((set_in->options & OPTION_NOHDRS) ||
 			(set_out->options & OPTION_NOHDRS)) {
 		errno = EINVAL;
-		ERR(
-		"the NOHDRS poolset option is not supported in local poolset files");
+		ERR_WO_ERRNO(
+			"the NOHDRS poolset option is not supported in local poolset files");
 		return -1;
 	}
 
@@ -370,30 +374,31 @@ identify_transform_operation(struct poolset_compare_status *set_in_s,
 	for (unsigned r = 0; r < set_in_s->nreplicas; ++r) {
 		unsigned c = replica_counterpart(r, set_in_s);
 		if (c != UNDEF_REPLICA) {
-			LOG(2, "replica %u has a counterpart %u", r,
+			CORE_LOG_DEBUG("replica %u has a counterpart %u", r,
 					set_in_s->replica[r]);
 			has_replica_to_keep = 1;
 			REP_HEALTH(set_out_hs, c)->pool_size =
 					REP_HEALTH(set_in_hs, r)->pool_size;
 		} else {
-			LOG(2, "replica %u has no counterpart", r);
+			CORE_LOG_NOTICE("replica %u has no counterpart", r);
 			is_removing_replicas = 1;
 		}
 	}
 
 	/* make sure we have at least one replica to keep */
 	if (!has_replica_to_keep) {
-		ERR("there must be at least one replica left");
+		ERR_WO_ERRNO("there must be at least one replica left");
 		return NOT_TRANSFORMABLE;
 	}
 
 	/* check if there are replicas to be added */
 	for (unsigned r = 0; r < set_out_s->nreplicas; ++r) {
 		if (replica_counterpart(r, set_out_s) == UNDEF_REPLICA) {
-			LOG(2, "Replica %u from output set has no counterpart",
+			CORE_LOG_NOTICE(
+					"Replica %u from output set has no counterpart",
 					r);
 			if (is_removing_replicas) {
-				ERR(
+				ERR_WO_ERRNO(
 				"adding and removing replicas at the same time is not allowed");
 				return NOT_TRANSFORMABLE;
 			}
@@ -407,7 +412,7 @@ identify_transform_operation(struct poolset_compare_status *set_in_s,
 	if (!is_removing_replicas && !is_adding_replicas &&
 			(set_in_s->flags & OPTION_SINGLEHDR) ==
 				(set_out_s->flags & OPTION_SINGLEHDR)) {
-		ERR("both poolsets are equal");
+		ERR_WO_ERRNO("both poolsets are equal");
 		return NOT_TRANSFORMABLE;
 	}
 
@@ -415,7 +420,7 @@ identify_transform_operation(struct poolset_compare_status *set_in_s,
 	if ((is_removing_replicas || is_adding_replicas) &&
 			(set_in_s->flags & OPTION_SINGLEHDR) !=
 				(set_out_s->flags & OPTION_SINGLEHDR)) {
-		ERR(
+		ERR_WO_ERRNO(
 		"cannot add/remove replicas and change the SINGLEHDR option at the same time");
 		return NOT_TRANSFORMABLE;
 	}
@@ -459,8 +464,8 @@ do_added_parts_exist(struct pool_set *set,
 				return -1;
 
 			if (exists && !rep->part[p].is_dev_dax) {
-				LOG(1, "part file %s exists",
-						rep->part[p].path);
+				CORE_LOG_ERROR("part file %s exists",
+					rep->part[p].path);
 				return 1;
 			}
 			errno = oerrno;
@@ -500,7 +505,8 @@ copy_replica_data_fw(struct pool_set *set_dst, struct pool_set *set_src,
 	LOG(3, "set_in %p, set_out %p, repn %u", set_src, set_dst, repn);
 	ssize_t pool_size = replica_get_pool_size(set_src, repn);
 	if (pool_size < 0) {
-		LOG(1, "getting pool size from replica %u failed", repn);
+		CORE_LOG_WARNING("getting pool size from replica %u failed",
+			repn);
 		pool_size = (ssize_t)set_src->poolsize;
 	}
 
@@ -527,7 +533,8 @@ copy_replica_data_bw(struct pool_set *set_dst, struct pool_set *set_src,
 	LOG(3, "set_in %p, set_out %p, repn %u", set_src, set_dst, repn);
 	ssize_t pool_size = replica_get_pool_size(set_src, repn);
 	if (pool_size < 0) {
-		LOG(1, "getting pool size from replica %u failed", repn);
+		CORE_LOG_WARNING("getting pool size from replica %u failed",
+			repn);
 		pool_size = (ssize_t)set_src->poolsize;
 	}
 
@@ -557,8 +564,9 @@ create_missing_headers(struct pool_set *set, unsigned repn)
 		util_pool_hdr2attr(&attr, src_hdr);
 		attr.features.incompat &= (uint32_t)(~POOL_FEAT_SINGLEHDR);
 		if (util_header_create(set, repn, p, &attr, 1) != 0) {
-			LOG(1, "part headers create failed for"
-					" replica %u part %u", repn, p);
+			CORE_LOG_ERROR(
+				"part headers create failed for replica %u part %u",
+			repn, p);
 			errno = EINVAL;
 			return -1;
 		}
@@ -602,7 +610,7 @@ fill_replica_struct_uuids(struct pool_set *set, unsigned repn)
 	memcpy(PART(rep, 0)->uuid, HDR(rep, 0)->uuid, POOL_HDR_UUID_LEN);
 	for (unsigned p = 1; p < rep->nhdrs; ++p) {
 		if (util_uuid_generate(rep->part[p].uuid) < 0) {
-			ERR("cannot generate part UUID");
+			ERR_WO_ERRNO("cannot generate part UUID");
 			errno = EINVAL;
 			return -1;
 		}
@@ -672,7 +680,7 @@ remove_hdrs_replica(struct pool_set *set_in, struct pool_set *set_out,
 
 	/* open all part files of the input replica */
 	if (replica_open_replica_part_files(set_in, repn)) {
-		LOG(1, "opening replica %u, part files failed", repn);
+		CORE_LOG_ERROR("opening replica %u, part files failed", repn);
 		ret = -1;
 		goto out;
 	}
@@ -682,14 +690,16 @@ remove_hdrs_replica(struct pool_set *set_in, struct pool_set *set_out,
 
 	/* map the whole input replica */
 	if (util_replica_open(set_in, repn, MAP_SHARED)) {
-		LOG(1, "opening input replica failed: replica %u", repn);
+		CORE_LOG_ERROR("opening input replica failed: replica %u",
+			repn);
 		ret = -1;
 		goto out_close;
 	}
 
 	/* map the whole output replica */
 	if (util_replica_open(set_out, repn, MAP_SHARED)) {
-		LOG(1, "opening output replica failed: replica %u", repn);
+		CORE_LOG_ERROR("opening output replica failed: replica %u",
+		repn);
 		ret = -1;
 		goto out_unmap_in;
 	}
@@ -724,7 +734,8 @@ add_hdrs_replica(struct pool_set *set_in, struct pool_set *set_out,
 
 	/* open all part files of the input replica */
 	if (replica_open_replica_part_files(set_in, repn)) {
-		LOG(1, "opening replica %u, part files failed", repn);
+		CORE_LOG_ERROR("opening replica %u, part files failed",
+			repn);
 		ret = -1;
 		goto out;
 	}
@@ -734,22 +745,25 @@ add_hdrs_replica(struct pool_set *set_in, struct pool_set *set_out,
 
 	/* map the whole input replica */
 	if (util_replica_open(set_in, repn, MAP_SHARED)) {
-		LOG(1, "opening input replica failed: replica %u", repn);
+		CORE_LOG_ERROR("opening input replica failed: replica %u",
+			repn);
 		ret = -1;
 		goto out_close;
 	}
 
 	/* map the whole output replica */
 	if (util_replica_open(set_out, repn, MAP_SHARED)) {
-		LOG(1, "opening output replica failed: replica %u", repn);
+		CORE_LOG_ERROR("opening output replica failed: replica %u",
+			repn);
 		ret = -1;
 		goto out_unmap_in;
 	}
 
 	/* generate new uuids for lacking headers */
 	if (fill_replica_struct_uuids(set_out, repn)) {
-		LOG(1, "generating lacking uuids for parts failed: replica %u",
-				repn);
+		CORE_LOG_ERROR(
+			"generating lacking uuids for parts failed: replica %u",
+			repn);
 		ret = -1;
 		goto out_unmap_out;
 	}
@@ -760,7 +774,8 @@ add_hdrs_replica(struct pool_set *set_in, struct pool_set *set_out,
 
 	/* create the missing headers */
 	if (create_missing_headers(set_out, repn)) {
-		LOG(1, "creating lacking headers failed: replica %u", repn);
+		CORE_LOG_ERROR("creating lacking headers failed: replica %u",
+			repn);
 		/*
 		 * copy the data back, so we could fall back to the original
 		 * state
@@ -800,7 +815,8 @@ remove_hdrs(struct pool_set *set_in, struct pool_set *set_out,
 			set_in, set_out, set_in_hs, flags);
 	for (unsigned r = 0; r < set_in->nreplicas; ++r) {
 		if (remove_hdrs_replica(set_in, set_out, r)) {
-			LOG(1, "removing headers from replica %u failed", r);
+			CORE_LOG_ERROR(
+				"removing headers from replica %u failed", r);
 			/* mark all previous replicas as damaged */
 			while (--r < set_in->nreplicas)
 				REP_HEALTH(set_in_hs, r)->flags |= IS_BROKEN;
@@ -824,7 +840,8 @@ add_hdrs(struct pool_set *set_in, struct pool_set *set_out,
 			set_in, set_out, set_in_hs, flags);
 	for (unsigned r = 0; r < set_in->nreplicas; ++r) {
 		if (add_hdrs_replica(set_in, set_out, r)) {
-			LOG(1, "adding headers to replica %u failed", r);
+			CORE_LOG_ERROR("adding headers to replica %u failed",
+				r);
 			/* mark all previous replicas as damaged */
 			while (--r < set_in->nreplicas)
 				REP_HEALTH(set_in_hs, r)->flags |= IS_BROKEN;
@@ -852,12 +869,12 @@ replica_transform(struct pool_set *set_in, struct pool_set *set_out,
 	struct poolset_health_status *set_in_hs = NULL;
 	if (replica_check_poolset_health(set_in, &set_in_hs,
 					0 /* called from transform */, flags)) {
-		ERR("source poolset health check failed");
+		ERR_WO_ERRNO("source poolset health check failed");
 		return -1;
 	}
 
 	if (!replica_is_poolset_healthy(set_in_hs)) {
-		ERR("source poolset is broken");
+		ERR_WO_ERRNO("source poolset is broken");
 		ret = -1;
 		errno = EINVAL;
 		goto free_hs_in;
@@ -868,7 +885,7 @@ replica_transform(struct pool_set *set_in, struct pool_set *set_out,
 
 	struct poolset_health_status *set_out_hs = NULL;
 	if (replica_create_poolset_health_status(set_out, &set_out_hs)) {
-		ERR("creating poolset health status failed");
+		ERR_WO_ERRNO("creating poolset health status failed");
 		ret = -1;
 		goto free_hs_in;
 	}
@@ -877,7 +894,7 @@ replica_transform(struct pool_set *set_in, struct pool_set *set_out,
 	struct poolset_compare_status *set_in_cs = NULL;
 	struct poolset_compare_status *set_out_cs = NULL;
 	if (compare_poolsets(set_in, set_out, &set_in_cs, &set_out_cs)) {
-		ERR("comparing poolsets failed");
+		ERR_WO_ERRNO("comparing poolsets failed");
 		ret = -1;
 		goto free_hs_out;
 	}
@@ -886,7 +903,7 @@ replica_transform(struct pool_set *set_in, struct pool_set *set_out,
 			set_out_cs, set_in_hs, set_out_hs);
 
 	if (operation == NOT_TRANSFORMABLE) {
-		LOG(1, "poolsets are not transformable");
+		CORE_LOG_ERROR("poolsets are not transformable");
 		ret = -1;
 		errno = EINVAL;
 		goto free_cs;
@@ -896,15 +913,15 @@ replica_transform(struct pool_set *set_in, struct pool_set *set_out,
 		if (!is_dry_run(flags) &&
 				remove_hdrs(set_in, set_out, set_in_hs,
 						flags)) {
-			ERR("removing headers failed; falling back to the "
-					"input poolset");
+			ERR_WO_ERRNO(
+				"removing headers failed; falling back to the input poolset");
 			if (replica_sync(set_in, set_in_hs,
 					flags | IS_TRANSFORMED)) {
-				LOG(1, "falling back to the input poolset "
-						"failed");
+				CORE_LOG_ERROR(
+					"falling back to the input poolset failed");
 			} else {
-				LOG(1, "falling back to the input poolset "
-						"succeeded");
+				CORE_LOG_HARK(
+					"falling back to the input poolset succeeded");
 			}
 			ret = -1;
 		}
@@ -914,15 +931,15 @@ replica_transform(struct pool_set *set_in, struct pool_set *set_out,
 	if (operation == ADD_HDRS) {
 		if (!is_dry_run(flags) &&
 				add_hdrs(set_in, set_out, set_in_hs, flags)) {
-			ERR("adding headers failed; falling back to the "
-					"input poolset");
+			ERR_WO_ERRNO(
+				"adding headers failed; falling back to the input poolset");
 			if (replica_sync(set_in, set_in_hs,
 					flags | IS_TRANSFORMED)) {
-				LOG(1, "falling back to the input poolset "
-						"failed");
+				CORE_LOG_ERROR(
+					"falling back to the input poolset failed");
 			} else {
-				LOG(1, "falling back to the input poolset "
-						"succeeded");
+				CORE_LOG_HARK(
+					"falling back to the input poolset succeeded");
 			}
 			ret = -1;
 		}
@@ -934,7 +951,7 @@ replica_transform(struct pool_set *set_in, struct pool_set *set_out,
 		 * check if any of the parts that are to be added already exists
 		 */
 		if (do_added_parts_exist(set_out, set_out_hs)) {
-			ERR("some parts being added already exist");
+			ERR_WO_ERRNO("some parts being added already exist");
 			ret = -1;
 			errno = EINVAL;
 			goto free_cs;
