@@ -7,7 +7,7 @@ import testframework as t
 from testframework import granularity as g
 
 
-@t.require_build(['debug', 'release'])
+@t.require_build(['debug', 'nondebug'])
 class EX_LIBPMEM2(t.Test):
     test_type = t.Medium
     file_size = 1 * t.MiB
@@ -104,7 +104,6 @@ class TEST501(EX_LIBPMEM2_TEST5):  # to be removed when fixed
     pass
 
 
-@t.windows_exclude
 # XXX disable the test for `memcheck' and 'helgrind'
 # until https://github.com/pmem/pmdk/issues/5638 is fixed.
 # @t.require_valgrind_disabled('memcheck', 'helgrind')
