@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2015-2020, Intel Corporation */
+/* Copyright 2015-2023, Intel Corporation */
 
 /*
  * obj_lane.c -- unit test for lanes
@@ -292,8 +292,6 @@ main(int argc, char *argv[])
 {
 	START(argc, argv, "obj_lane");
 
-	obj_init();
-
 	if (argc != 2)
 		usage(argv[0]);
 
@@ -317,15 +315,5 @@ main(int argc, char *argv[])
 		usage(argv[0]);
 	}
 
-	obj_fini();
 	DONE(NULL);
 }
-
-#ifdef _MSC_VER
-/*
- * Since libpmemobj is linked statically,
- * we need to invoke its ctor/dtor.
- */
-MSVC_CONSTR(libpmemobj_init)
-MSVC_DESTR(libpmemobj_fini)
-#endif
