@@ -1,56 +1,10 @@
-/*
- * Copyright 2015-2018, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2015-2023, Intel Corporation */
 
 /*
  * obj_list.c -- unit tests for list module
  */
 
-/*
- * XXX - On VC++, this file must be compiled as C++ to have __typeof__ defined.
- * However, the rest of the files (libpmemobj source) are still compiled as C.
- * To avoid issues with 'C' linkage the entire file is in 'extern "C"' block.
- */
-#if defined(__cplusplus) && defined(_MSC_VER)
-extern "C" {
-
-/*
- * XXX - Templates cannot be used with 'C' linkage, so for the purpose
- * of this test, we override template-based definition of __typeof__ with
- * a simple alias to decltype.
- */
-#define __typeof__(p) decltype(p)
-
-#endif
-
 #include "obj_list.h"
 
 /* global handle to pmemobj pool */
@@ -452,7 +406,3 @@ main(int argc, char *argv[])
 
 	DONE(NULL);
 }
-
-#if defined(__cplusplus) && defined(_MSC_VER)
-}
-#endif
