@@ -1,34 +1,5 @@
-/*
- * Copyright 2016-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2016-2023, Intel Corporation */
 
 /*
  * obj_tx_lock.c -- unit test for pmemobj_tx_lock()
@@ -149,10 +120,6 @@ do_tx_add_locks_nested_all(struct transaction_data *data)
 static void *
 do_tx_add_taken_lock(struct transaction_data *data)
 {
-	/* wrlocks on Windows don't detect self-deadlocks */
-#ifdef _WIN32
-	(void) data;
-#else
 	UT_ASSERTeq(pmemobj_rwlock_wrlock(Pop, &data->rwlocks[0]), 0);
 
 	TX_BEGIN(Pop) {
@@ -162,7 +129,7 @@ do_tx_add_taken_lock(struct transaction_data *data)
 
 	UT_ASSERTne(pmemobj_rwlock_trywrlock(Pop, &data->rwlocks[0]), 0);
 	UT_ASSERTeq(pmemobj_rwlock_unlock(Pop, &data->rwlocks[0]), 0);
-#endif
+
 	return NULL;
 }
 
@@ -173,10 +140,6 @@ do_tx_add_taken_lock(struct transaction_data *data)
 static void *
 do_tx_lock_fail(struct transaction_data *data)
 {
-	/* wrlocks on Windows don't detect self-deadlocks */
-#ifdef _WIN32
-	(void) data;
-#else
 	UT_ASSERTeq(pmemobj_rwlock_wrlock(Pop, &data->rwlocks[0]), 0);
 	int ret = 0;
 	/* return errno and abort transaction */
@@ -195,10 +158,33 @@ do_tx_lock_fail(struct transaction_data *data)
 				POBJ_XLOCK_NO_ABORT);
 	} TX_ONCOMMIT {
 		UT_ASSERTne(ret, 0);
+		UT_ASSERTeq(pmemobj_rwlock_unlock(Pop, &data->rwlocks[0]), 0);
 	} TX_ONABORT {
 		UT_ASSERT(0);
 	} TX_END
-#endif
+	/* return ret without abort transaction */
+	UT_ASSERTeq(pmemobj_rwlock_wrlock(Pop, &data->rwlocks[0]), 0);
+	TX_BEGIN(Pop) {
+		pmemobj_tx_set_failure_behavior(POBJ_TX_FAILURE_RETURN);
+		ret = pmemobj_tx_lock(TX_PARAM_RWLOCK, &data->rwlocks[0]);
+	} TX_ONCOMMIT {
+		UT_ASSERTne(ret, 0);
+		UT_ASSERTeq(pmemobj_rwlock_unlock(Pop, &data->rwlocks[0]), 0);
+	} TX_ONABORT {
+		UT_ASSERT(0);
+	} TX_END
+	/* return ret without abort transaction */
+	UT_ASSERTeq(pmemobj_rwlock_wrlock(Pop, &data->rwlocks[0]), 0);
+	TX_BEGIN(Pop) {
+		pmemobj_tx_set_failure_behavior(POBJ_TX_FAILURE_RETURN);
+		ret = pmemobj_tx_xlock(TX_PARAM_RWLOCK, &data->rwlocks[0], 0);
+	} TX_ONCOMMIT {
+		UT_ASSERTne(ret, 0);
+		UT_ASSERTeq(pmemobj_rwlock_unlock(Pop, &data->rwlocks[0]), 0);
+	} TX_ONABORT {
+		UT_ASSERT(0);
+	} TX_END
+
 	return NULL;
 }
 
