@@ -22,12 +22,13 @@ class PMEM2_INTEGRATION(t.Test):
         ctx.exec('pmem2_integration', self.test_case, filepath)
 
 
-@t.require_devdax(t.DevDax('devdax'))
+@t.require_devdax(t.DevDax('devdax'), max_size=1 * t.GiB)
 class PMEM2_INTEGRATION_DEV_DAXES(t.Test):
     test_type = t.Medium
 
     def run(self, ctx):
         dd = ctx.devdaxes.devdax
+        print(dd.path)
         ctx.exec('pmem2_integration', self.test_case, dd.path)
 
 
@@ -65,7 +66,6 @@ class TEST2(PMEM2_INTEGRATION):
 
 
 @t.require_valgrind_enabled('pmemcheck')
-@t.windows_exclude
 class TEST3(PMEM2_INTEGRATION_DEV_DAXES):
     """check if Valgrind registers data writing on DevDax"""
     test_case = "test_register_pmem"
@@ -157,7 +157,6 @@ class TEST14(PMEM2_INTEGRATION):
     test_case = "test_len_not_aligned"
 
 
-@t.windows_exclude
 class TEST15(PMEM2_INTEGRATION_DEV_DAXES):
     """test not aligned length on DevDax"""
     test_case = "test_len_not_aligned"
@@ -168,7 +167,6 @@ class TEST16(PMEM2_INTEGRATION):
     test_case = "test_len_aligned"
 
 
-@t.windows_exclude
 class TEST17(PMEM2_INTEGRATION_DEV_DAXES):
     """test aligned length on DevDax"""
     test_case = "test_len_aligned"
@@ -179,7 +177,6 @@ class TEST18(PMEM2_INTEGRATION):
     test_case = "test_offset_not_aligned"
 
 
-@t.windows_exclude
 class TEST19(PMEM2_INTEGRATION_DEV_DAXES):
     """test unaligned offset"""
     test_case = "test_offset_not_aligned"
@@ -190,7 +187,6 @@ class TEST20(PMEM2_INTEGRATION):
     test_case = "test_offset_aligned"
 
 
-@t.windows_exclude
 class TEST21(PMEM2_INTEGRATION_DEV_DAXES):
     """test unaligned offset"""
     test_case = "test_offset_aligned"
@@ -254,32 +250,37 @@ class TEST32(PMEM2_INTEGRATION):
     test_case = "test_source_anon_zero_len"
 
 
-@t.windows_exclude
-class TEST33(PMEM2_INTEGRATION_DEV_DAXES):
+# The Valgrind pmemcheck tool does not have a notion of a deep flush.
+# Whereas from the persistency point of view, the deep flush test cases are
+# trivial so running them under pmemcheck produces little value.
+# At the same time, they touch a whole provided device DAX space hence running
+# them under pmemcheck is extensively time-consuming.
+@t.require_valgrind_disabled('pmemcheck')
+class PMEM2_INTEGRATION_DEV_DAXES_NO_PMEMCHECK(PMEM2_INTEGRATION_DEV_DAXES):
+    pass
+
+
+class TEST33(PMEM2_INTEGRATION_DEV_DAXES_NO_PMEMCHECK):
     """test valid case of pmem2_deep_sflush"""
     test_case = "test_deep_flush_valid"
 
 
-@t.windows_exclude
-class TEST34(PMEM2_INTEGRATION_DEV_DAXES):
+class TEST34(PMEM2_INTEGRATION_DEV_DAXES_NO_PMEMCHECK):
     """test deep flush with range out of map"""
     test_case = "test_deep_flush_e_range_behind"
 
 
-@t.windows_exclude
-class TEST35(PMEM2_INTEGRATION_DEV_DAXES):
+class TEST35(PMEM2_INTEGRATION_DEV_DAXES_NO_PMEMCHECK):
     """test deep flush with range out of map"""
     test_case = "test_deep_flush_e_range_before"
 
 
-@t.windows_exclude
-class TEST36(PMEM2_INTEGRATION_DEV_DAXES):
+class TEST36(PMEM2_INTEGRATION_DEV_DAXES_NO_PMEMCHECK):
     """test deep flush with part of map"""
     test_case = "test_deep_flush_slice"
 
 
-@t.windows_exclude
-class TEST37(PMEM2_INTEGRATION_DEV_DAXES):
+class TEST37(PMEM2_INTEGRATION_DEV_DAXES_NO_PMEMCHECK):
     """test deep flush with overlapping part"""
     test_case = "test_deep_flush_overlap"
 
@@ -299,7 +300,6 @@ class TES40(PMEM2_INTEGRATION):
     test_case = "test_map_from_existing_map"
 
 
-@t.windows_exclude
 class TEST41(PMEM2_INTEGRATION_DEV_DAXES):
     """compare normal map vs map_from_existing on devdax"""
     test_case = "test_map_from_existing"
