@@ -1,11 +1,10 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2020, Intel Corporation */
+/* Copyright 2020-2024, Intel Corporation */
 
 /*
  * pmem2_persist_valgrind.c -- pmem2_persist_valgrind tests
  */
 
-#include "out.h"
 #include "unittest.h"
 #include "ut_pmem2_utils.h"
 
@@ -208,9 +207,6 @@ int
 main(int argc, char *argv[])
 {
 	START(argc, argv, "pmem2_persist_valgrind");
-	out_init("pmem2_persist_valgrind", "TEST_LOG_LEVEL", "TEST_LOG_FILE", 0,
-			0);
 	TEST_CASE_PROCESS(argc, argv, test_cases, NTESTS);
-	out_fini();
 	DONE(NULL);
 }
