@@ -35,7 +35,6 @@ class PMEM2_VM_RESERVATION_ASYNC(t.Test):
                  filesize, self.threads, self.ops_per_thread)
 
 
-@t.windows_exclude
 @t.require_devdax(t.DevDax('devdax1'))
 class PMEM2_VM_RESERVATION_DEVDAX(t.Test):
     test_type = t.Short
@@ -49,7 +48,6 @@ class PMEM2_VM_RESERVATION_DEVDAX(t.Test):
             ctx.exec('pmem2_vm_reservation', self.test_case, dd.path)
 
 
-@t.windows_exclude
 @t.require_devdax(t.DevDax('devdax1'))
 class PMEM2_VM_RESERVATION_ASYNC_DEVDAX(t.Test):
     test_type = t.Short
@@ -169,11 +167,13 @@ class TEST13(PMEM2_VM_RESERVATION_DEVDAX):
 
 class TEST14(PMEM2_VM_RESERVATION):
     """create a vm reservation with with error injection"""
+    labels = ['fault_injection']
     test_case = "test_vm_reserv_new_alloc_enomem"
 
 
 class TEST15(PMEM2_VM_RESERVATION_DEVDAX):
     """DevDax create a vm reservation with with error injection"""
+    labels = ['fault_injection']
     test_case = "test_vm_reserv_new_alloc_enomem"
 
 
@@ -289,6 +289,8 @@ class TEST30(PMEM2_VM_RESERVATION):
     test_case = "test_vm_reserv_map_invalid_granularity"
 
 
+# XXX - https://github.com/pmem/pmdk/issues/5707
+@t.DISABLED()
 class TEST31(PMEM2_VM_RESERVATION_ASYNC):
     """
     map and unmap asynchronously multiple times to the whole vm reservation
