@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2018-2019, Intel Corporation */
+/* Copyright 2018-2023, Intel Corporation */
 
 /*
  * pmem_deep_persist.c -- unit test for pmem_deep_persist()
@@ -106,11 +106,3 @@ main(int argc, char *argv[])
 	DONE(NULL);
 
 }
-
-#ifdef _MSC_VER
-/*
- * Since libpmemobj is linked statically, we need to invoke its ctor/dtor.
- */
-MSVC_CONSTR(libpmemobj_init)
-MSVC_DESTR(libpmemobj_fini)
-#endif
