@@ -1,13 +1,11 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2014-2019, Intel Corporation */
+/* Copyright 2014-2023, Intel Corporation */
 
 /*
  * spoil.c -- pmempool spoil command source file
  */
 #include <features.h>
-#ifndef __FreeBSD__
 #define __USE_UNIX98
-#endif
 #include <unistd.h>
 #include <stdio.h>
 #include <getopt.h>
@@ -27,7 +25,6 @@
 #include <libpmem.h>
 #include "common.h"
 #include "output.h"
-#include "btt.h"
 #include "set.h"
 #include "util.h"
 
@@ -496,44 +493,6 @@ pmemspoil_parse_args(struct pmemspoil *psp, char *appname,
 	return 0;
 }
 
-/*
- * pmemspoil_get_arena_offset -- get offset to arena of given id
- */
-static uint64_t
-pmemspoil_get_arena_offset(struct pmemspoil *psp, uint32_t id,
-		uint64_t start_offset)
-{
-	struct btt_info *infop = calloc(sizeof(struct btt_info), 1);
-	if (!infop)
-		err(1, NULL);
-
-	infop->nextoff = start_offset;
-
-	uint64_t offset = 0;
-	ssize_t ret = 0;
-	id++;
-	while (id > 0) {
-		if (infop->nextoff == 0) {
-			free(infop);
-			return 0;
-		}
-		offset = offset + infop->nextoff;
-		if ((ret = pmemspoil_read(psp, infop,
-				sizeof(*infop), offset))) {
-			free(infop);
-			return 0;
-		}
-
-		btt_info_convert2h(infop);
-
-		id--;
-	}
-
-	free(infop);
-
-	return offset;
-}
-
 /*
  * pmemspoil_check_field -- compares field name and moves pointer if the same
  */
@@ -779,297 +738,6 @@ pmemspoil_process_pool_hdr(struct pmemspoil *psp,
 	return PROCESS_RET;
 }
 
-/*
- * pmemspoil_process_btt_info_struct -- process btt_info at given offset
- */
-static int
-pmemspoil_process_btt_info_struct(struct pmemspoil *psp,
-		struct pmemspoil_list *pfp, uint64_t offset)
-{
-	struct btt_info btt_info;
-
-	if (pmemspoil_read(psp, &btt_info, sizeof(btt_info), offset))
-		return -1;
-
-	PROCESS_BEGIN(psp, pfp) {
-		PROCESS_FIELD(&btt_info, sig, char);
-		PROCESS_FIELD(&btt_info, uuid, char);
-		PROCESS_FIELD(&btt_info, parent_uuid, char);
-		PROCESS_FIELD_LE(&btt_info, flags, uint32_t);
-		PROCESS_FIELD_LE(&btt_info, major, uint16_t);
-		PROCESS_FIELD_LE(&btt_info, minor, uint16_t);
-		PROCESS_FIELD_LE(&btt_info, external_lbasize, uint32_t);
-		PROCESS_FIELD_LE(&btt_info, external_nlba, uint32_t);
-		PROCESS_FIELD_LE(&btt_info, internal_lbasize, uint32_t);
-		PROCESS_FIELD_LE(&btt_info, internal_nlba, uint32_t);
-		PROCESS_FIELD_LE(&btt_info, nfree, uint32_t);
-		PROCESS_FIELD_LE(&btt_info, infosize, uint32_t);
-		PROCESS_FIELD_LE(&btt_info, nextoff, uint64_t);
-		PROCESS_FIELD_LE(&btt_info, dataoff, uint64_t);
-		PROCESS_FIELD_LE(&btt_info, mapoff, uint64_t);
-		PROCESS_FIELD_LE(&btt_info, flogoff, uint64_t);
-		PROCESS_FIELD_LE(&btt_info, infooff, uint64_t);
-		PROCESS_FIELD(&btt_info, unused, char);
-		PROCESS_FIELD_LE(&btt_info, checksum, uint64_t);
-	} PROCESS_END
-
-	if (PROCESS_STATE == PROCESS_STATE_FIELD) {
-		if (pmemspoil_write(psp, &btt_info, sizeof(btt_info), offset))
-			return -1;
-	}
-
-	return PROCESS_RET;
-}
-
-/*
- * pmemspoil_process_btt_info_backup -- process btt_info backup fields
- */
-static int
-pmemspoil_process_btt_info_backup(struct pmemspoil *psp,
-		struct pmemspoil_list *pfp, uint32_t index)
-{
-	struct btt_info btt_info_backup;
-
-	if (pmemspoil_read(psp, &btt_info_backup, sizeof(btt_info_backup),
-				psp->arena_offset))
-		return -1;
-
-	uint64_t backup_offset = psp->arena_offset +
-			le64toh(btt_info_backup.infooff);
-
-	return pmemspoil_process_btt_info_struct(psp, pfp, backup_offset);
-}
-
-/*
- * pmemspoil_process_btt_info -- process btt_info fields
- */
-static int
-pmemspoil_process_btt_info(struct pmemspoil *psp,
-		struct pmemspoil_list *pfp, uint32_t index)
-{
-	return pmemspoil_process_btt_info_struct(psp, pfp, psp->arena_offset);
-}
-
-/*
- * pmemspoil_process_btt_map -- process btt map fields
- */
-static int
-pmemspoil_process_btt_map(struct pmemspoil *psp,
-		struct pmemspoil_list *pfp, uint32_t index)
-{
-	struct btt_info btt_info;
-
-	if (pmemspoil_read(psp, &btt_info, sizeof(btt_info),
-			psp->arena_offset))
-		return -1;
-
-	btt_info_convert2h(&btt_info);
-
-	uint64_t mapoff = psp->arena_offset + btt_info.mapoff;
-	uint64_t mapsize = roundup(btt_info.external_nlba * BTT_MAP_ENTRY_SIZE,
-							BTT_ALIGNMENT);
-
-	uint32_t *mapp = malloc(mapsize);
-	if (!mapp)
-		err(1, NULL);
-	int ret = 0;
-
-	if (pmemspoil_read(psp, mapp, mapsize, mapoff)) {
-		ret = -1;
-	} else {
-		uint32_t v;
-		if (sscanf(pfp->value, "0x%x", &v) != 1 &&
-		    sscanf(pfp->value, "%u", &v) != 1) {
-			ret = -1;
-		} else {
-			mapp[index] = v;
-			if (pmemspoil_write(psp, mapp, mapsize, mapoff))
-				ret = -1;
-		}
-	}
-
-	free(mapp);
-	return ret;
-}
-
-/*
- * pmemspoil_process_btt_flog -- process btt_flog first or second fields
- */
-static int
-pmemspoil_process_btt_nflog(struct pmemspoil *psp,
-	struct pmemspoil_list *pfp, uint64_t arena_offset, int off,
-	uint32_t index)
-{
-	struct btt_info btt_info;
-	if (pmemspoil_read(psp, &btt_info, sizeof(btt_info), arena_offset))
-		return -1;
-
-	btt_info_convert2h(&btt_info);
-
-	uint64_t flogoff = arena_offset + btt_info.flogoff;
-	uint64_t flogsize = btt_info.nfree *
-		roundup(2 * sizeof(struct btt_flog), BTT_FLOG_PAIR_ALIGN);
-	flogsize = roundup(flogsize, BTT_ALIGNMENT);
-
-	uint8_t *flogp = malloc(flogsize);
-	if (!flogp)
-		err(1, NULL);
-
-	int ret = 0;
-
-	if (pmemspoil_read(psp, flogp, flogsize, flogoff)) {
-		ret = -1;
-		goto error;
-	}
-
-	struct btt_flog *flog_entryp = (struct btt_flog *)(flogp +
-			index * BTT_FLOG_PAIR_ALIGN);
-	if (off)
-		flog_entryp++;
-
-	PROCESS_BEGIN(psp, pfp) {
-		PROCESS_FIELD_LE(flog_entryp, lba, uint32_t);
-		PROCESS_FIELD_LE(flog_entryp, old_map, uint32_t);
-		PROCESS_FIELD_LE(flog_entryp, new_map, uint32_t);
-		PROCESS_FIELD_LE(flog_entryp, seq, uint32_t);
-	} PROCESS_END
-
-	if (PROCESS_STATE == PROCESS_STATE_FIELD) {
-		if (pmemspoil_write(psp, flogp, flogsize, flogoff)) {
-			ret = -1;
-			goto error;
-		}
-	}
-	ret = PROCESS_RET;
-error:
-	free(flogp);
-
-	return ret;
-}
-
-/*
- * pmemspoil_process_btt_flog -- process first btt flog entry
- */
-static int
-pmemspoil_process_btt_flog(struct pmemspoil *psp, struct pmemspoil_list *pfp,
-		uint32_t index)
-{
-	return pmemspoil_process_btt_nflog(psp, pfp,
-		psp->arena_offset, 0, index);
-}
-
-/*
- * pmemspoil_process_btt_flog_prime -- process second btt flog entry
- */
-static int
-pmemspoil_process_btt_flog_prime(struct pmemspoil *psp,
-		struct pmemspoil_list *pfp, uint32_t index)
-{
-	return pmemspoil_process_btt_nflog(psp, pfp,
-		psp->arena_offset, 1, index);
-}
-
-/*
- * pmemspoil_process_arena -- process arena fields
- */
-static int
-pmemspoil_process_arena(struct pmemspoil *psp,
-		struct pmemspoil_list *pfp, uint64_t arena_offset)
-{
-	if (!arena_offset)
-		return -1;
-
-	struct btt_info btt_info;
-	if (pmemspoil_read(psp, &btt_info, sizeof(btt_info), arena_offset))
-		return -1;
-
-	btt_info_convert2h(&btt_info);
-	psp->arena_offset = arena_offset;
-
-	PROCESS_BEGIN(psp, pfp) {
-		PROCESS(btt_info, PROCESS_INDEX, 1, uint32_t);
-		PROCESS(btt_info_backup, PROCESS_INDEX, 1, uint32_t);
-		PROCESS(btt_map, PROCESS_INDEX, btt_info.external_nlba,
-			uint32_t);
-		PROCESS(btt_flog, PROCESS_INDEX, btt_info.nfree, uint32_t);
-		PROCESS(btt_flog_prime, PROCESS_INDEX, btt_info.nfree,
-			uint32_t);
-	} PROCESS_END
-
-	return PROCESS_RET;
-}
-
-/*
- * pmemspoil_process_pmemblk -- process pmemblk fields
- */
-static int
-pmemspoil_process_pmemblk(struct pmemspoil *psp,
-		struct pmemspoil_list *pfp, void *arg)
-{
-	struct pmemblk pmemblk;
-	if (pmemspoil_read(psp, &pmemblk, sizeof(pmemblk), 0))
-		return -1;
-
-	PROCESS_BEGIN(psp, pfp) {
-		PROCESS_FIELD_LE(&pmemblk, bsize, uint32_t);
-
-		PROCESS(arena,
-			pmemspoil_get_arena_offset(psp, PROCESS_INDEX,
-				ALIGN_UP(sizeof(struct pmemblk),
-					BLK_FORMAT_DATA_ALIGN)),
-			UINT32_MAX, uint64_t);
-	} PROCESS_END
-
-	if (PROCESS_STATE == PROCESS_STATE_FIELD) {
-		if (pmemspoil_write(psp, &pmemblk, sizeof(pmemblk), 0))
-			return -1;
-	}
-
-	return PROCESS_RET;
-}
-
-/*
- * pmemspoil_process_bttdevice -- process btt device fields
- */
-static int
-pmemspoil_process_bttdevice(struct pmemspoil *psp,
-		struct pmemspoil_list *pfp, void *arg)
-{
-	PROCESS_BEGIN(psp, pfp) {
-		PROCESS(arena,
-			pmemspoil_get_arena_offset(psp, PROCESS_INDEX,
-					ALIGN_UP(sizeof(struct pool_hdr),
-					BTT_ALIGNMENT)),
-			UINT32_MAX, uint64_t);
-	} PROCESS_END
-	return PROCESS_RET;
-}
-
-/*
- * pmemspoil_process_pmemlog -- process pmemlog fields
- */
-static int
-pmemspoil_process_pmemlog(struct pmemspoil *psp,
-		struct pmemspoil_list *pfp, void *arg)
-{
-	struct pmemlog pmemlog;
-	if (pmemspoil_read(psp, &pmemlog, sizeof(pmemlog), 0))
-		return -1;
-
-	PROCESS_BEGIN(psp, pfp) {
-		PROCESS_FIELD_LE(&pmemlog, start_offset, uint64_t);
-		PROCESS_FIELD_LE(&pmemlog, end_offset, uint64_t);
-		PROCESS_FIELD_LE(&pmemlog, write_offset, uint64_t);
-	} PROCESS_END
-
-	if (PROCESS_STATE == PROCESS_STATE_FIELD) {
-		if (pmemspoil_write(psp, &pmemlog, sizeof(pmemlog), 0))
-			return -1;
-	}
-
-	return PROCESS_RET;
-}
-
 /*
  * pmemspoil_process_run -- process pmemobj chunk as run
  */
@@ -1231,10 +899,7 @@ pmemspoil_process(struct pmemspoil *psp,
 {
 	PROCESS_BEGIN(psp, pfp) {
 		PROCESS(pool_hdr, NULL, 1, void *);
-		PROCESS(pmemlog, NULL, 1, void *);
-		PROCESS(pmemblk, NULL, 1, void *);
 		PROCESS(pmemobj, NULL, 1, void *);
-		PROCESS(bttdevice, NULL, 1, void *);
 	} PROCESS_END
 
 	return PROCESS_RET;
@@ -1246,19 +911,6 @@ pmemspoil_process(struct pmemspoil *psp,
 int
 main(int argc, char *argv[])
 {
-#ifdef _WIN32
-	util_suppress_errmsg();
-	wchar_t **wargv = CommandLineToArgvW(GetCommandLineW(), &argc);
-	for (int i = 0; i < argc; i++) {
-		argv[i] = util_toUTF8(wargv[i]);
-		if (argv[i] == NULL) {
-			for (i--; i >= 0; i--)
-				free(argv[i]);
-			outv_err("Error during arguments conversion\n");
-			return 1;
-		}
-	}
-#endif
 	char *appname = basename(argv[0]);
 	util_init();
 	int ret = 0;
@@ -1315,9 +967,5 @@ error:
 	pool_set_file_close(psp->pfile);
 
 	free(psp);
-#ifdef _WIN32
-	for (int i = argc; i > 0; i--)
-		free(argv[i - 1]);
-#endif
 	return ret;
 }
