@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2019-2023, Intel Corporation
+# Copyright 2019-2024, Intel Corporation
 
 """Base tests class and its functionalities.
 
@@ -66,6 +66,7 @@ from os import path
 
 from configurator import Configurator
 from consts import LIBS_LIST, ROOTDIR
+import granularity as g
 import futils
 import test_types
 import shutil
@@ -143,9 +144,14 @@ class BaseTest(metaclass=_TestCase):
     Attributes:
         enabled (bool): True if test is meant to be executed, False otherwise.
             Defaults to True.
+        force_disabled (bool): True if the test is explicitle excluded from
+            execution e.g. in case the test fails permanently.
+            Defaults to False.
         ctx (Context): context affiliated with the test
     """
     enabled = True
+    force_disabled = False
+    labels = []
 
     def __init__(self):
         self.ctx = None
@@ -162,6 +168,7 @@ class BaseTest(metaclass=_TestCase):
             c (Context): test context
         """
         self.ctx = c
+        start_time = None  # assign in case clean() or setup() fail
 
         try:
             # pre-execution cleanup
@@ -179,7 +186,8 @@ class BaseTest(metaclass=_TestCase):
             self.check(c)
 
         except futils.Fail:
-            self.elapsed = (datetime.now() - start_time).total_seconds()
+            if start_time is not None:
+                self.elapsed = (datetime.now() - start_time).total_seconds()
             self._on_fail()
             raise
 
@@ -192,7 +200,8 @@ class BaseTest(metaclass=_TestCase):
             msg = '{}: {}TIMEOUT{}\t({})'.format(self, futils.Color.RED,
                                                  futils.Color.END,
                                                  self.ctx)
-            self.elapsed = (datetime.now() - start_time).total_seconds()
+            if start_time is not None:
+                self.elapsed = (datetime.now() - start_time).total_seconds()
             raise futils.Fail(msg)
 
         else:
@@ -332,6 +341,13 @@ class Test(BaseTest):
         self.env.update(self._get_utenv())
         self.env.update(self._debug_log_env())
         self.ctx.add_env(self.env)
+        # disable shutdown state control for non-pmem (Page granularity)
+        if isinstance(ctx.granularity, g.Page):
+            pmemobj_conf = os.getenv('PMEMOBJ_CONF', default='')
+            if 'sds.at_create=0' not in pmemobj_conf:
+                env = dict()
+                env['PMEMOBJ_CONF'] = 'sds.at_create=0'
+                self.ctx.add_env(env)
 
         self.remove_log_files()
 
@@ -358,8 +374,7 @@ class Test(BaseTest):
                 not f[before_suffix].isdigit()
 
         match_files = filter(is_matchfile, cwd_listdir)
-        prefix = 'perl ' if sys.platform == 'win32' else ''
-        match_cmd = prefix + path.join(ROOTDIR, 'match')
+        match_cmd = path.join(ROOTDIR, 'match')
 
         for mf in match_files:
             cmd = '{} {}'.format(match_cmd, mf)
