@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2019-2020, Intel Corporation
+# Copyright 2019-2023, Intel Corporation
 #
 """Parser for user provided test configuration"""
 
@@ -136,7 +136,7 @@ def _str2ctx(config):
     convert_internal('test_type', test_types._TestType)
     convert_internal('granularity', granularity.Granularity)
 
-    if config['force_enable'] is not None:
+    if config['force_enable'] is not None and config['force_enable'] != 'none':
         config['force_enable'] = next(
             t for t in vg.TOOLS
             if t.name.lower() == config['force_enable'])
@@ -186,9 +186,8 @@ class Configurator():
 
             # device_dax_path may be either a single string with path
             # or a sequence of paths
-            if sys.platform != 'win32':
-                config.device_dax_path = futils.to_list(config.device_dax_path,
-                                                        str)
+            config.device_dax_path = futils.to_list(config.device_dax_path,
+                                                    str)
 
             return config
 
@@ -274,6 +273,9 @@ class Configurator():
         parser.add_argument('--fail-on-skip', dest='fail_on_skip',
                             action='store_const', const=True,
                             help='Skipping tests also fail')
+        parser.add_argument('--test-label', dest='test_label', default='',
+                            action='store',
+                            help='Run only tests marked with the label')
 
         tracers = parser.add_mutually_exclusive_group()
         tracers.add_argument('--tracer', dest='tracer', help='run C binary '
@@ -286,9 +288,10 @@ class Configurator():
         tracers.add_argument('--cgdb', dest='tracer', action='store_const',
                              const='cgdb --args', help='run cgdb as a tracer')
 
-        if sys.platform != 'win32':
-            fe_choices = [str(t) for t in vg.TOOLS]
-            parser.add_argument('--force-enable', choices=fe_choices,
-                                default=None)
+        fe_choices = [str(t) for t in vg.TOOLS] + ['none']
+        parser.add_argument('--force-enable', choices=fe_choices, default=None,
+                            help='allows to force the use of a specific '
+                            'valgrind tool, but skips tests where the tool is '
+                            'explicitly disabled')
 
         return parser
