@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: BSD-3-Clause */
-/* Copyright 2014-2023, Intel Corporation */
+/* Copyright 2014-2024, Intel Corporation */
 
 /*
  * unittest.h -- the mundane stuff shared by all unit tests
@@ -25,10 +25,9 @@
  * and the error message includes the calling context information (file:line).
  * in general, using the all-caps version of a call means you're using the
  * unittest.h version which does the most common checking for you.  so
- * calling VMEM_CREATE() instead of vmem_create() returns the same
+ * calling MALLOC() instead of malloc() returns the same
  * thing, but can never return an error since the unit test library checks for
- * it.  * for routines like vmem_delete() there is no corresponding
- * VMEM_DELETE() because there's no error to check for.
+ * it.
  *
  * all unit tests should use the same initialization:
  *
@@ -57,8 +56,6 @@
 
 #include <libpmem.h>
 #include <libpmem2.h>
-#include <libpmemblk.h>
-#include <libpmemlog.h>
 #include <libpmemobj.h>
 #include <libpmempool.h>
 
@@ -80,9 +77,7 @@ extern "C" {
 #include <sys/stat.h>
 #include <sys/mman.h>
 #include <sys/file.h>
-#ifndef __FreeBSD__
 #include <sys/mount.h>
-#endif
 #include <fcntl.h>
 #include <signal.h>
 #include <errno.h>
@@ -92,26 +87,14 @@ extern "C" {
 #include "os.h"
 #include "os_thread.h"
 #include "util.h"
+#include "log_internal.h"
+#include "core_assert.h"
 
 int ut_get_uuid_str(char *);
 #define UT_MAX_ERR_MSG 128
 #define UT_POOL_HDR_UUID_STR_LEN 37 /* uuid string length */
 #define UT_POOL_HDR_UUID_GEN_FILE "/proc/sys/kernel/random/uuid"
 
-/* XXX - fix this temp hack dup'ing util_strerror when we get mock for win */
-void ut_strerror(int errnum, char *buff, size_t bufflen);
-
-/* XXX - eliminate duplicated definitions in unittest.h and util.h */
-#ifdef _WIN32
-static inline int ut_util_statW(const wchar_t *path,
-	os_stat_t *st_bufp) {
-	int retVal = _wstat64(path, st_bufp);
-	/* clear unused bits to avoid confusion */
-	st_bufp->st_mode &= 0600;
-	return retVal;
-}
-#endif
-
 /*
  * unit test support...
  */
@@ -119,10 +102,6 @@ void ut_start(const char *file, int line, const char *func,
 	int argc, char * const argv[], const char *fmt, ...)
 	__attribute__((format(printf, 6, 7)));
 
-void ut_startW(const char *file, int line, const char *func,
-	int argc, wchar_t * const argv[], const char *fmt, ...)
-	__attribute__((format(printf, 6, 7)));
-
 void NORETURN ut_done(const char *file, int line, const char *func,
 	const char *fmt, ...)
 	__attribute__((format(printf, 4, 5)));
@@ -139,37 +118,12 @@ void ut_err(const char *file, int line, const char *func,
 	__attribute__((format(printf, 4, 5)));
 
 /* indicate the start of the test */
-#ifndef _WIN32
 #define START(argc, argv, ...)\
-    ut_start(__FILE__, __LINE__, __func__, argc, argv, __VA_ARGS__)
-#else
-#define START(argc, argv, ...)\
-	wchar_t **wargv = CommandLineToArgvW(GetCommandLineW(), &argc);\
-	for (int i = 0; i < argc; i++) {\
-		argv[i] = ut_toUTF8(wargv[i]);\
-		if (argv[i] == NULL) {\
-			for (i--; i >= 0; i--)\
-				free(argv[i]);\
-			UT_FATAL("Error during arguments conversion\n");\
-		}\
-	}\
 	ut_start(__FILE__, __LINE__, __func__, argc, argv, __VA_ARGS__)
-#endif
-
-/* indicate the start of the test */
-#define STARTW(argc, argv, ...)\
-    ut_startW(__FILE__, __LINE__, __func__, argc, argv, __VA_ARGS__)
 
 /* normal exit from test */
-#ifndef _WIN32
 #define DONE(...)\
     ut_done(__FILE__, __LINE__, __func__, __VA_ARGS__)
-#else
-#define DONE(...)\
-	for (int i = argc; i > 0; i--)\
-		free(argv[i - 1]);\
-	ut_done(__FILE__, __LINE__, __func__, __VA_ARGS__)
-#endif
 
 #define DONEW(...)\
     ut_done(__FILE__, __LINE__, __func__, __VA_ARGS__)
@@ -192,36 +146,38 @@ void ut_err(const char *file, int line, const char *func,
 /*
  * assertions...
  */
+#define UT_ASSERT_MSG(FORMAT, ...) \
+	UT_FATAL("assertion failure: " FORMAT, ##__VA_ARGS__)
 
 /* assert a condition is true at runtime */
 #define UT_ASSERT_rt(cnd)\
-	((void)((cnd) || (ut_fatal(__FILE__, __LINE__, __func__,\
-	"assertion failure: %s", #cnd), 0)))
+	((void)((cnd) || (UT_ASSERT_MSG("%s", #cnd), 0)))
 
 /* assertion with extra info printed if assertion fails at runtime */
 #define UT_ASSERTinfo_rt(cnd, info) \
-	((void)((cnd) || (ut_fatal(__FILE__, __LINE__, __func__,\
-	"assertion failure: %s (%s)", #cnd, info), 0)))
+	((void)((cnd) || (UT_ASSERT_MSG("%s (%s)", #cnd, info), 0)))
 
 /* assert two integer values are equal at runtime */
-#define UT_ASSERTeq_rt(lhs, rhs)\
-	((void)(((lhs) == (rhs)) || (ut_fatal(__FILE__, __LINE__, __func__,\
-	"assertion failure: %s (0x%llx) == %s (0x%llx)", #lhs,\
+#define UT_ASSERTeq_rt(lhs, rhs) \
+	((void)(((lhs) == (rhs)) || \
+	(UT_ASSERT_MSG("%s (0x%llx) == %s (0x%llx)", #lhs, \
 	(unsigned long long)(lhs), #rhs, (unsigned long long)(rhs)), 0)))
 
 /* assert two integer values are not equal at runtime */
-#define UT_ASSERTne_rt(lhs, rhs)\
-	((void)(((lhs) != (rhs)) || (ut_fatal(__FILE__, __LINE__, __func__,\
-	"assertion failure: %s (0x%llx) != %s (0x%llx)", #lhs,\
+#define UT_ASSERTne_rt(lhs, rhs) \
+	((void)(((lhs) != (rhs)) || \
+	(UT_ASSERT_MSG("%s (0x%llx) != %s (0x%llx)", #lhs, \
 	(unsigned long long)(lhs), #rhs, (unsigned long long)(rhs)), 0)))
 
+/* assert two strings are equal at runtime */
+#define UT_ASSERTstreq_rt(__s1, __s2) \
+	((void)((__s1 == NULL && __s2 == NULL) || \
+		(strcmp(__s1, __s2) == 0) || \
+		(UT_ASSERT_MSG("%s: \"%s\" != %s", #__s1, __s1, __s2), 0)))
+
 #if defined(__CHECKER__)
 #define UT_COMPILE_ERROR_ON(cond)
 #define UT_ASSERT_COMPILE_ERROR_ON(cond)
-#elif defined(_MSC_VER)
-#define UT_COMPILE_ERROR_ON(cond) C_ASSERT(!(cond))
-/* XXX - can't be done with C_ASSERT() unless we have __builtin_constant_p() */
-#define UT_ASSERT_COMPILE_ERROR_ON(cond) (void)(cond)
 #else
 #define UT_COMPILE_ERROR_ON(cond) ((void)sizeof(char[(cond) ? -1 : 1]))
 #ifndef __cplusplus
@@ -232,7 +188,7 @@ void ut_err(const char *file, int line, const char *func,
  */
 #define UT_ASSERT_COMPILE_ERROR_ON(cond) UT_ASSERT_rt(!(cond))
 #endif /* __cplusplus */
-#endif /* _MSC_VER */
+#endif /* __CHECKER__ */
 
 /* assert a condition is true */
 #define UT_ASSERT(cnd)\
@@ -278,11 +234,18 @@ void ut_err(const char *file, int line, const char *func,
 #define UT_ASSERTrange(ptr, start, size)\
 	((void)(((uintptr_t)(ptr) >= (uintptr_t)(start) &&\
 	(uintptr_t)(ptr) < (uintptr_t)(start) + (uintptr_t)(size)) ||\
-	(ut_fatal(__FILE__, __LINE__, __func__,\
-	"assert failure: %s (%p) is outside range [%s (%p), %s (%p))", #ptr,\
+	(UT_ASSERT_MSG("%s (%p) is outside range [%s (%p), %s (%p))", #ptr,\
 	(void *)(ptr), #start, (void *)(start), #start"+"#size,\
 	(void *)((uintptr_t)(start) + (uintptr_t)(size))), 0)))
 
+/* assert strings are equal */
+#define UT_ASSERTstreq(__s1, __s2) \
+	do { \
+		if (__builtin_constant_p(__s1)) \
+			UT_FATAL("UT_ASSERTstreq the first param must not be " \
+				"const"); \
+		UT_ASSERTstreq_rt(__s1, __s2); \
+	} while (0)
 /*
  * memory allocation...
  */
@@ -381,9 +344,6 @@ int ut_posix_fallocate(const char *file, int line, const char *func, int fd,
 int ut_stat(const char *file, int line, const char *func, const char *path,
     os_stat_t *st_bufp);
 
-int ut_statW(const char *file, int line, const char *func, const wchar_t *path,
-	os_stat_t *st_bufp);
-
 int ut_fstat(const char *file, int line, const char *func, int fd,
     os_stat_t *st_bufp);
 
@@ -480,9 +440,6 @@ int ut_snprintf(const char *file, int line, const char *func,
 #define STAT(path, st_bufp)\
     ut_stat(__FILE__, __LINE__, __func__, path, st_bufp)
 
-#define STATW(path, st_bufp)\
-    ut_statW(__FILE__, __LINE__, __func__, path, st_bufp)
-
 #define FTRUNCATE(fd, length)\
     ut_ftruncate(__FILE__, __LINE__, __func__, fd, length)
 
@@ -518,15 +475,10 @@ int ut_snprintf(const char *file, int line, const char *func,
 	ut_snprintf(__FILE__, __LINE__, __func__, \
 			str, size, format, __VA_ARGS__)
 
-#ifndef _WIN32
 #define ut_jmp_buf_t sigjmp_buf
 #define ut_siglongjmp(b) siglongjmp(b, 1)
 #define ut_sigsetjmp(b) sigsetjmp(b, 1)
-#else
-#define ut_jmp_buf_t jmp_buf
-#define ut_siglongjmp(b) longjmp(b, 1)
-#define ut_sigsetjmp(b) setjmp(b)
-#endif
+
 void ut_suppress_errmsg(void);
 void ut_unsuppress_errmsg(void);
 void ut_suppress_crt_assert(void);
@@ -560,47 +512,17 @@ int ut_thread_join(const char *file, int line, const char *func,
 #define THREAD_JOIN(thread, value_ptr)\
     ut_thread_join(__FILE__, __LINE__, __func__, thread, value_ptr)
 
-/*
- * processes...
- */
-#ifdef _WIN32
-intptr_t ut_spawnv(int argc, const char **argv, ...);
-#endif
-
 /*
  * mocks...
  *
  * NOTE: On Linux, function mocking is implemented using wrapper functions.
  * See "--wrap" option of the GNU linker.
- * There is no such feature in VC++, so on Windows we do the mocking at
- * compile time, by redefining symbol names:
- * - all the references to <symbol> are replaced with <__wrap_symbol>
- *   in all the compilation units, except the one where the <symbol> is
- *   defined and the test source file
- * - the original definition of <symbol> is replaced with <__real_symbol>
- * - a wrapper function <__wrap_symbol> must be defined in the test program
- *   (it may still call the original function via <__real_symbol>)
- * Such solution seems to be sufficient for the purpose of our tests, even
- * though it has some limitations.  I.e. it does no work well with malloc/free,
- * so to wrap the system memory allocator functions, we use the built-in
- * feature of all the PMDK libraries, allowing to override default memory
- * allocator with the custom one.
  */
-#ifndef _WIN32
 #define _FUNC_REAL_DECL(name, ret_type, ...)\
 	ret_type __real_##name(__VA_ARGS__) __attribute__((unused));
-#else
-#define _FUNC_REAL_DECL(name, ret_type, ...)\
-	ret_type name(__VA_ARGS__);
-#endif
 
-#ifndef _WIN32
 #define _FUNC_REAL(name)\
 	__real_##name
-#else
-#define _FUNC_REAL(name)\
-	name
-#endif
 
 #define RCOUNTER(name)\
 	_rcounter##name
@@ -608,13 +530,22 @@ intptr_t ut_spawnv(int argc, const char **argv, ...);
 #define FUNC_MOCK_RCOUNTER_SET(name, val)\
     RCOUNTER(name) = val;
 
-#define FUNC_MOCK(name, ret_type, ...)\
+#define _FUNC_MOCK(type, name, ret_type, ...)\
 	_FUNC_REAL_DECL(name, ret_type, ##__VA_ARGS__)\
-	static unsigned RCOUNTER(name);\
+	type unsigned RCOUNTER(name);\
 	ret_type __wrap_##name(__VA_ARGS__);\
 	ret_type __wrap_##name(__VA_ARGS__) {\
 		switch (util_fetch_and_add32(&RCOUNTER(name), 1)) {
 
+#define FUNC_MOCK(name, ret_type, ...) \
+	_FUNC_MOCK(static, name, ret_type, ##__VA_ARGS__)
+
+#define FUNC_MOCK_NONSTATIC(name, ret_type, ...) \
+	_FUNC_MOCK(, name, ret_type, ##__VA_ARGS__)
+
+#define FUNC_MOCK_EXTERN(name) \
+	extern unsigned RCOUNTER(name)
+
 #define FUNC_MOCK_DLLIMPORT(name, ret_type, ...)\
 	__declspec(dllimport) _FUNC_REAL_DECL(name, ret_type, ##__VA_ARGS__)\
 	static unsigned RCOUNTER(name);\
@@ -688,6 +619,16 @@ TEST_CASE_PROCESS(int argc, char *argv[],
 	if (argc < 2)
 		UT_FATAL("usage: %s <test case> [<args>]", argv[0]);
 
+	if (strcmp("ALL", argv[1]) == 0) {
+		for (size_t i = 0; i < ntests; i++) {
+			int ret = test_cases[i].func(&test_cases[i], 0, NULL);
+			if (ret < 0)
+				UT_FATAL("Test %s return negative result",
+					test_cases[i].name);
+		}
+		return;
+	}
+
 	for (int i = 1; i < argc; i++) {
 		char *str_test = argv[i];
 		const int args_off = i + 1;
