@@ -1,6 +1,6 @@
 #
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2014-2023, Intel Corporation
+# Copyright 2014-2024, Intel Corporation
 #
 # Copyright (c) 2016, Microsoft Corporation. All rights reserved.
 #
@@ -46,6 +46,10 @@ fi
 . ../testconfig.sh
 . ../envconfig.sh
 
+# Required for easy force-enable condition failure detection.
+# Please see require_valgrind() for details.
+FORCED_CHECK_TYPE=$CHECK_TYPE
+
 if [ -t 1 ]; then
 	IS_TERMINAL_STDOUT=YES
 fi
@@ -83,6 +87,10 @@ function interactive_green() {
 	interactive_color 2 "$@"
 }
 
+function interactive_yellow() {
+	interactive_color 3 "$@"
+}
+
 function verbose_msg() {
 	if [ "$UNITTEST_LOG_LEVEL" -ge 2 ]; then
 		echo "$*"
@@ -117,7 +125,8 @@ fi
 [ "$CHECK_TYPE" ] || CHECK_TYPE=auto
 [ "$CHECK_POOL" ] || CHECK_POOL=0
 [ "$VERBOSE" ] || VERBOSE=0
-[ -n "${SUFFIX+x}" ] || SUFFIX="😘⠏⠍⠙⠅ɗPMDKӜ⥺🙋"
+[ "$TEST_LABEL" ] || TEST_LABEL=
+[ -n "${SUFFIX+x}" ] || SUFFIX=""
 
 export UNITTEST_LOG_LEVEL GREP TEST FS BUILD CHECK_TYPE CHECK_POOL VERBOSE SUFFIX
 
@@ -126,21 +135,20 @@ LIB_TOOLS="../../tools"
 # Paths to some useful tools
 [ "$PMEMPOOL" ] || PMEMPOOL=$LIB_TOOLS/pmempool/pmempool
 [ "$DAXIO" ] || DAXIO=$LIB_TOOLS/daxio/daxio
-[ "$PMEMSPOIL" ] || PMEMSPOIL=$TOOLS/pmemspoil/pmemspoil.static-nondebug
-[ "$BTTCREATE" ] || BTTCREATE=$TOOLS/bttcreate/bttcreate.static-nondebug
+[ "$PMEMSPOIL" ] || PMEMSPOIL=$TOOLS/pmemspoil/pmemspoil.static_nondebug
 [ "$PMEMWRITE" ] || PMEMWRITE=$TOOLS/pmemwrite/pmemwrite
 [ "$PMEMALLOC" ] || PMEMALLOC=$TOOLS/pmemalloc/pmemalloc
 [ "$PMEMOBJCLI" ] || PMEMOBJCLI=$TOOLS/pmemobjcli/pmemobjcli
-[ "$PMEMDETECT" ] || PMEMDETECT=$TOOLS/pmemdetect/pmemdetect.static-nondebug
+[ "$PMEMDETECT" ] || PMEMDETECT=$TOOLS/pmemdetect/pmemdetect.static_nondebug
 [ "$PMREORDER" ] || PMREORDER=$LIB_TOOLS/pmreorder/pmreorder.py
 [ "$FIP" ] || FIP=$TOOLS/fip/fip
 [ "$DDMAP" ] || DDMAP=$TOOLS/ddmap/ddmap
 [ "$CMPMAP" ] || CMPMAP=$TOOLS/cmpmap/cmpmap
 [ "$EXTENTS" ] || EXTENTS=$TOOLS/extents/extents
-[ "$FALLOCATE_DETECT" ] || FALLOCATE_DETECT=$TOOLS/fallocate_detect/fallocate_detect.static-nondebug
+[ "$FALLOCATE_DETECT" ] || FALLOCATE_DETECT=$TOOLS/fallocate_detect/fallocate_detect.static_nondebug
 [ "$OBJ_VERIFY" ] || OBJ_VERIFY=$TOOLS/obj_verify/obj_verify
-[ "$USC_PERMISSION" ] || USC_PERMISSION=$TOOLS/usc_permission_check/usc_permission_check.static-nondebug
-[ "$ANONYMOUS_MMAP" ] || ANONYMOUS_MMAP=$TOOLS/anonymous_mmap/anonymous_mmap.static-nondebug
+[ "$USC_PERMISSION" ] || USC_PERMISSION=$TOOLS/usc_permission_check/usc_permission_check.static_nondebug
+[ "$ANONYMOUS_MMAP" ] || ANONYMOUS_MMAP=$TOOLS/anonymous_mmap/anonymous_mmap.static_nondebug
 
 # force globs to fail if they don't match
 shopt -s failglob
@@ -165,39 +173,26 @@ DIR_SRC="../.."
 VALGRIND_SUPP="--suppressions=../ld.supp \
 	--suppressions=../memcheck-libunwind.supp \
 	--suppressions=../memcheck-ndctl.supp"
-if [ "$(uname -s)" = "FreeBSD" ]; then
-	DATE="gdate"
-	DD="gdd"
-	FALLOCATE="mkfile"
-	VM_OVERCOMMIT="[ $(sysctl vm.overcommit | awk '{print $2}') == 0 ]"
-	RM_ONEFS="-x"
-	STAT_MODE="-f%Lp"
-	STAT_PERM="-f%Sp"
-	STAT_SIZE="-f%z"
-	STRACE="truss"
-	VALGRIND_SUPP="$VALGRIND_SUPP --suppressions=../freebsd.supp"
-else
-	DATE="date"
-	DD="dd"
-	FALLOCATE="fallocate -l"
-	VM_OVERCOMMIT="[ $(cat /proc/sys/vm/overcommit_memory) != 2 ]"
-	RM_ONEFS="--one-file-system"
-	STAT_MODE="-c%a"
-	STAT_PERM="-c%A"
-	STAT_SIZE="-c%s"
-	STRACE="strace"
-fi
+DATE="date"
+DD="dd"
+FALLOCATE="fallocate -l"
+VM_OVERCOMMIT="[ $(cat /proc/sys/vm/overcommit_memory) != 2 ]"
+RM_ONEFS="--one-file-system"
+STAT_MODE="-c%a"
+STAT_PERM="-c%A"
+STAT_SIZE="-c%s"
+STRACE="strace"
 
 case "$BUILD"
 in
-debug|static-debug)
+debug|static_debug)
 	if [ -z "$PMDK_LIB_PATH_DEBUG" ]; then
 		PMDK_LIB_PATH=../../debug
 	else
 		PMDK_LIB_PATH=$PMDK_LIB_PATH_DEBUG
 	fi
 	;;
-nondebug|static-nondebug)
+nondebug|static_nondebug)
 	if [ -z "$PMDK_LIB_PATH_NONDEBUG" ]; then
 		PMDK_LIB_PATH=../../nondebug
 	else
@@ -287,7 +282,7 @@ else
 		DIR=/dev/null/not_existing_dir/$DIRSUFFIX/$curtestdir$UNITTEST_NUM
 		;;
 	*)
-		verbose_msg "$UNITTEST_NAME: SKIP fs-type $FS (not configured)"
+		verbose_msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) fs-type $FS (not configured)"
 		exit 0
 		;;
 	esac
@@ -299,10 +294,6 @@ fi
 #
 export PMEM_LOG_LEVEL=3
 export PMEM_LOG_FILE=pmem$UNITTEST_NUM.log
-export PMEMBLK_LOG_LEVEL=3
-export PMEMBLK_LOG_FILE=pmemblk$UNITTEST_NUM.log
-export PMEMLOG_LOG_LEVEL=3
-export PMEMLOG_LOG_FILE=pmemlog$UNITTEST_NUM.log
 export PMEMOBJ_LOG_LEVEL=3
 export PMEMOBJ_LOG_FILE=pmemobj$UNITTEST_NUM.log
 export PMEMPOOL_LOG_LEVEL=3
@@ -822,7 +813,7 @@ function check_pool() {
 		then
 			echo "$UNITTEST_NAME: checking consistency of pool ${1}"
 		fi
-		${PMEMPOOL}.static-nondebug check $1 2>&1 1>>$CHECK_POOL_LOG_FILE
+		${PMEMPOOL}.static_nondebug check $1 2>&1 1>>$CHECK_POOL_LOG_FILE
 	fi
 }
 
@@ -849,11 +840,11 @@ function check_pools() {
 #
 function require_unlimited_vm() {
 	if grep -q "^mmu[[:blank:]]*: sv39" /proc/cpuinfo; then
-		msg "$UNITTEST_NAME: SKIP required: 4+ level virtual memory"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) required: 4+ level virtual memory"
 		exit 0
 	fi
 	$VM_OVERCOMMIT && [ $(ulimit -v) = "unlimited" ] && return
-	msg "$UNITTEST_NAME: SKIP required: overcommit_memory enabled and unlimited virtual memory"
+	msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) required: overcommit_memory enabled and unlimited virtual memory"
 	exit 0
 }
 
@@ -867,7 +858,7 @@ function require_linked_with_ndctl() {
 		fatal "$UNITTEST_NAME: ERROR: require_linked_with_ndctl() requires one argument - an executable file"
 	local lddndctl=$(ldd $1 | $GREP -ce "libndctl")
 	[ "$lddndctl" == "1" ] && return
-	msg "$UNITTEST_NAME: SKIP required: executable $1 linked with libndctl"
+	msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) required: executable $1 linked with libndctl"
 	exit 0
 }
 
@@ -876,13 +867,13 @@ function require_linked_with_ndctl() {
 #
 function require_sudo_allowed() {
 	if [ "$ENABLE_SUDO_TESTS" != "y" ]; then
-		msg "$UNITTEST_NAME: SKIP: tests using 'sudo' are not enabled in testconfig.sh (ENABLE_SUDO_TESTS)"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): tests using 'sudo' are not enabled in testconfig.sh (ENABLE_SUDO_TESTS)"
 		exit 0
 	fi
 
 	if ! sh -c "timeout --signal=SIGKILL --kill-after=3s 3s sudo date" >/dev/null 2>&1
 	then
-		msg "$UNITTEST_NAME: SKIP required: sudo allowed"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) required: sudo allowed"
 		exit 0
 	fi
 }
@@ -893,16 +884,7 @@ function require_sudo_allowed() {
 function require_no_superuser() {
 	local user_id=$(id -u)
 	[ "$user_id" != "0" ] && return
-	msg "$UNITTEST_NAME: SKIP required: run without superuser rights"
-	exit 0
-}
-
-#
-# require_no_freebsd -- Skip test on FreeBSD
-#
-function require_no_freebsd() {
-	[ "$(uname -s)" != "FreeBSD" ] && return
-	msg "$UNITTEST_NAME: SKIP: Not supported on FreeBSD"
+	msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) required: run without superuser rights"
 	exit 0
 }
 
@@ -911,7 +893,7 @@ function require_no_freebsd() {
 #
 function require_procfs() {
 	mount | grep -q "/proc" && return
-	msg "$UNITTEST_NAME: SKIP: /proc not mounted"
+	msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): /proc not mounted"
 	exit 0
 }
 
@@ -923,7 +905,7 @@ function require_arch() {
 	for i in "$@"; do
 		[[ "$(uname -m)" == "$i" ]] && return
 	done
-	msg "$UNITTEST_NAME: SKIP: Only supported on $1"
+	msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): Only supported on $1"
 	exit 0
 }
 
@@ -934,7 +916,7 @@ function require_arch() {
 function exclude_arch() {
 	for i in "$@"; do
 		if [[ "$(uname -m)" == "$i" ]]; then
-			msg "$UNITTEST_NAME: SKIP: Not supported on $1"
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): Not supported on $1"
 			exit 0
 		fi
 	done
@@ -951,6 +933,7 @@ function require_x86_64() {
 # require_ppc64 -- Skip tests if the running platform is not ppc64 or ppc64le
 #
 function require_ppc64() {
+	exit 0
 	require_arch "ppc64" "ppc64le" "ppc64el"
 }
 
@@ -983,7 +966,7 @@ function require_test_type() {
 			;;
 		esac
 	done
-	verbose_msg "$UNITTEST_NAME: SKIP test-type $TEST ($* required)"
+	verbose_msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) test-type $TEST ($* required)"
 	exit 0
 }
 
@@ -991,7 +974,7 @@ function require_test_type() {
 # require_dev_dax_region -- check if region id file exist for dev dax
 #
 function require_dev_dax_region() {
-	local prefix="$UNITTEST_NAME: SKIP"
+	local prefix="$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM)"
 	local cmd="$PMEMDETECT -r"
 
 	for path in ${DEVICE_DAX_PATH[@]}
@@ -1044,7 +1027,7 @@ function require_dev_dax_node() {
 
 	local min=$1
 
-	local prefix="$UNITTEST_NAME: SKIP"
+	local prefix="$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM)"
 	if [ ${#DEVICE_DAX_PATH[@]} -lt $min ]; then
 		msg "$prefix DEVICE_DAX_PATH does not specify enough dax devices (min: $min)"
 		exit 0
@@ -1076,7 +1059,7 @@ function require_dev_dax_node() {
 #
 function require_ndctl_enable() {
 	if ! is_ndctl_enabled $PMEMPOOL$EXE &> /dev/null ; then
-		msg "$UNITTEST_NAME: SKIP: ndctl is disabled - binary not compiled with libndctl"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): ndctl is disabled - binary not compiled with libndctl"
 		exit 0
 	fi
 
@@ -1119,7 +1102,7 @@ get_node_devdax_path() {
 dax_device_zero() {
 	for path in ${DEVICE_DAX_PATH[@]}
 	do
-		${PMEMPOOL}.static-debug rm -f $path
+		${PMEMPOOL}.static_debug rm -f $path
 	done
 }
 
@@ -1221,7 +1204,7 @@ function require_dax_device_alignments() {
 		done
 
 		if [ $i -eq $cnt ]; then
-			msg "$UNITTEST_NAME: SKIP DEVICE_DAX_PATH"\
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) DEVICE_DAX_PATH"\
 				"does not specify enough dax devices or they don't have required alignments (min: $#, alignments: $*)"
 
 			exit 0
@@ -1256,7 +1239,7 @@ function require_fs_type() {
 			([ -n "${FORCE_FS:+x}" ] && [ "$type" = "any" ] &&
 			[ "$FS" != "none" ]) && return
 	done
-	verbose_msg "$UNITTEST_NAME: SKIP fs-type $FS ($* required)"
+	verbose_msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) fs-type $FS ($* required)"
 	exit 0
 }
 
@@ -1272,7 +1255,7 @@ function require_native_fallocate() {
 	set -e
 
 	if [ $status -eq 1 ]; then
-		msg "$UNITTEST_NAME: SKIP: filesystem does not support fallocate"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): filesystem does not support fallocate"
 		exit 0
 	elif [ $status -ne 0 ]; then
 		msg "$UNITTEST_NAME: fallocate_detect failed"
@@ -1285,8 +1268,10 @@ function require_native_fallocate() {
 #
 function require_usc_permission() {
 	set +e
-	$USC_PERMISSION $1 2> $DIR/usc_permission.txt
+	touch $1/test.tmp
+	$USC_PERMISSION $1/test.tmp 2> $DIR/usc_permission.txt
 	status=$?
+	rm -rf $1/test.tmp
 	set -e
 
 	# check if there were any messages printed to stderr, skip test if there were
@@ -1295,7 +1280,7 @@ function require_usc_permission() {
 	rm -f $DIR/usc_permission.txt
 
 	if [ $status -eq 1 ] || [ $usc_stderr -ne 0 ]; then
-		msg "$UNITTEST_NAME: SKIP: missing permissions to read usc"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): missing permissions to read usc"
 		exit 0
 	elif [ $status -ne 0 ]; then
 		msg "$UNITTEST_NAME: usc_permission_check failed"
@@ -1318,7 +1303,7 @@ function require_fs_name() {
 		fi
 	done
 
-	msg "$UNITTEST_NAME: SKIP file system $fsname ($* required)"
+	msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) file system $fsname ($* required)"
 	exit 0
 }
 
@@ -1330,7 +1315,7 @@ function require_build_type() {
 	do
 		[ "$type" = "$BUILD" ] && return
 	done
-	verbose_msg "$UNITTEST_NAME: SKIP build-type $BUILD ($* required)"
+	verbose_msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) build-type $BUILD ($* required)"
 	exit 0
 }
 
@@ -1339,7 +1324,7 @@ function require_build_type() {
 #
 function require_command() {
 	if ! which $1 >/dev/null 2>&1; then
-		msg "$UNITTEST_NAME: SKIP: '$1' command required"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): '$1' command required"
 		exit 0
 	fi
 }
@@ -1364,17 +1349,17 @@ function require_kernel_module() {
 		[ "$MODINFO" == "" ] && \
 			[ -x /sbin/modinfo ] && MODINFO=/sbin/modinfo
 		[ "$MODINFO" == "" ] && \
-			msg "$UNITTEST_NAME: SKIP: modinfo command required" && \
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): modinfo command required" && \
 			exit 0
 	else
 		[ ! -x $MODINFO ] && \
-			msg "$UNITTEST_NAME: SKIP: modinfo command required" && \
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): modinfo command required" && \
 			exit 0
 	fi
 
 	$MODINFO -F name $MODULE &>/dev/null && true
 	if [ $? -ne 0 ]; then
-		msg "$UNITTEST_NAME: SKIP: '$MODULE' kernel module required"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): '$MODULE' kernel module required"
 		exit 0
 	fi
 }
@@ -1386,12 +1371,12 @@ function require_kernel_module() {
 function require_pkg() {
 	if ! command -v pkg-config 1>/dev/null
 	then
-		msg "$UNITTEST_NAME: SKIP pkg-config required"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) pkg-config required"
 		exit 0
 	fi
 
 	local COMMAND="pkg-config $1"
-	local MSG="$UNITTEST_NAME: SKIP '$1' package"
+	local MSG="$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) '$1' package"
 	if [ "$#" -eq "2" ]; then
 		COMMAND="$COMMAND --atleast-version $2"
 		MSG="$MSG (version >= $2)"
@@ -1419,7 +1404,9 @@ function configure_valgrind() {
 
 	if [ "$CHECK_TYPE" == "none" ]; then
 		if [ "$1" == "force-disable" ]; then
-			msg "$UNITTEST_NAME: all valgrind tests disabled"
+			# The test requires Valgrind to be disabled and no Valgrind tool
+			# is forced by the user. The requirement is met.
+			:
 		elif [ "$2" = "force-enable" ]; then
 			CHECK_TYPE="$1"
 			require_valgrind_tool $1 $3
@@ -1430,13 +1417,13 @@ function configure_valgrind() {
 		fi
 	else
 		if [ "$1" == "force-disable" ]; then
-			msg "$UNITTEST_NAME: SKIP RUNTESTS script parameter $CHECK_TYPE tries to enable valgrind test when all valgrind tests are disabled in TEST"
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) RUNTESTS.sh script parameter $CHECK_TYPE tries to enable valgrind test when all valgrind tests are disabled in TEST"
 			exit 0
 		elif [ "$CHECK_TYPE" != "$1" -a "$2" == "force-enable" ]; then
-			msg "$UNITTEST_NAME: SKIP RUNTESTS script parameter $CHECK_TYPE tries to enable different valgrind test than one defined in TEST"
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) RUNTESTS.sh script parameter $CHECK_TYPE tries to enable different valgrind test than one defined in TEST"
 			exit 0
 		elif [ "$CHECK_TYPE" == "$1" -a "$2" == "force-disable" ]; then
-			msg "$UNITTEST_NAME: SKIP RUNTESTS script parameter $CHECK_TYPE tries to enable test defined in TEST as force-disable"
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) RUNTESTS.sh script parameter $CHECK_TYPE tries to enable test defined in TEST as force-disable"
 			exit 0
 		fi
 		require_valgrind_tool $CHECK_TYPE $3
@@ -1460,6 +1447,11 @@ function valgrind_version_no_check() {
 #	valgrind package is installed
 #
 function require_valgrind() {
+	if [ "$DISABLE_VALGRIND_TESTS" == "1" ]; then
+		msg=$(interactive_yellow STDOUT "SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM):")
+		echo -e "$UNITTEST_NAME: $msg all Valgrind tests are disabled"
+		exit 0
+	fi
 	# bc is used inside valgrind_version_no_check
 	require_command bc
 	require_no_asan
@@ -1468,7 +1460,30 @@ function require_valgrind() {
 	local ret=$?
 	restore_exit_on_error
 	if [ $ret -ne 0 ]; then
-		msg "$UNITTEST_NAME: SKIP valgrind required"
+		# FORCED_CHECK_TYPE is a copy of CHECK_TYPE as it is provided by force-enable.
+		# This copy allowed us to workaround the overcomplicated legacy Valgrind processing logic
+		# and here just check whether any Valgrind tool has been force-enabled or not.
+		# Lack of Valgrind when it is force-enabled causes test failure.
+		# Lack of Valgrind, when it was just required by the given test, causes a skip.
+		if [ "$FORCED_CHECK_TYPE" != "none" ]; then
+			msg=$(interactive_red STDOUT "FAIL:")
+			echo -e "$UNITTEST_NAME: $msg Valgrind not installed"
+			exit 1
+		else
+			msg=$(interactive_yellow STDOUT "SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM):")
+			echo -e "$UNITTEST_NAME: $msg Valgrind required"
+			exit 0
+		fi
+	fi
+
+	# Check if Valgrind is enabled in the test build
+	disable_exit_on_error
+	../valgrind_check/valgrind_check
+	ret=$?
+	restore_exit_on_error
+	if [ $ret -ne 0 ]; then
+		msg=$(interactive_yellow STDOUT "SKIP:")
+		echo -e "$UNITTEST_NAME: $msg Valgrind is required but the Valgrind support has been disabled at compile time"
 		exit 0
 	fi
 }
@@ -1501,7 +1516,7 @@ function require_valgrind_tool() {
 	strings ${binary} 2>&1 | \
 	grep -q "compiled with support for Valgrind $tool" && true
 	if [ $? -ne 0 ]; then
-		msg "$UNITTEST_NAME: SKIP not compiled with support for Valgrind $tool"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) not compiled with support for Valgrind $tool"
 		exit 0
 	fi
 
@@ -1509,7 +1524,7 @@ function require_valgrind_tool() {
 		valgrind --tool=$tool --help 2>&1 | \
 		grep -qi "$tool is Copyright (c)" && true
 		if [ $? -ne 0 ]; then
-			msg "$UNITTEST_NAME: SKIP Valgrind with $tool required"
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) Valgrind with $tool required"
 			exit 0;
 		fi
 	fi
@@ -1517,12 +1532,12 @@ function require_valgrind_tool() {
 		out=`valgrind --tool=$tool --help 2>&1` && true
 		echo "$out" | grep -qi "$tool is Copyright (c)" && true
 		if [ $? -ne 0 ]; then
-			msg "$UNITTEST_NAME: SKIP Valgrind with $tool required"
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) Valgrind with $tool required"
 			exit 0;
 		fi
 		echo "$out" | grep -qi "expect-fence-after-clflush" && true
 		if [ $? -ne 0 ]; then
-			msg "$UNITTEST_NAME: SKIP pmemcheck does not support --expect-fence-after-clflush option. Please update it to the latest version."
+			msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) pmemcheck does not support --expect-fence-after-clflush option. Please update it to the latest version."
 			exit 0;
 		fi
 	fi
@@ -1559,7 +1574,7 @@ function require_no_asan_for() {
 	ASAN_ENABLED=$?
 	restore_exit_on_error
 	if [ "$ASAN_ENABLED" == "0" ]; then
-		msg "$UNITTEST_NAME: SKIP: ASAN enabled"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): ASAN enabled"
 		exit 0
 	fi
 }
@@ -1576,7 +1591,7 @@ function require_cxx11() {
 		echo y || echo n`
 
 	if [ "$CXX11_AVAILABLE" == "n" ]; then
-		msg "$UNITTEST_NAME: SKIP: C++11 required"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): C++11 required"
 		exit 0
 	fi
 }
@@ -1594,10 +1609,10 @@ function require_no_asan() {
 	nondebug)
 		require_no_asan_for ../../nondebug/libpmem.so
 		;;
-	static-debug)
+	static_debug)
 		require_no_asan_for ../../debug/libpmem.a
 		;;
-	static-nondebug)
+	static_nondebug)
 		require_no_asan_for ../../nondebug/libpmem.a
 		;;
 	esac
@@ -1608,7 +1623,7 @@ function require_no_asan() {
 #
 function require_tty() {
 	if ! tty >/dev/null; then
-		msg "$UNITTEST_NAME: SKIP no terminal"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) no terminal"
 		exit 0
 	fi
 }
@@ -1623,7 +1638,7 @@ function require_binary() {
 		fatal "require_binary: error: binary not provided"
 	fi
 	if [ ! -x "$1" ]; then
-		msg "$UNITTEST_NAME: SKIP no binary found"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) no binary found"
 		exit 0
 	fi
 
@@ -1645,7 +1660,11 @@ function require_sds() {
 	strings ${binary} 2>&1 | \
 		grep -q "compiled with support for shutdown state" && true
 	if [ $? -ne 0 ]; then
-		msg "$UNITTEST_NAME: SKIP not compiled with support for shutdown state"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) not compiled with support for shutdown state"
+		exit 0
+	fi
+	if [[ $PMEMOBJ_CONF = *'sds.at_create=0'* ]]; then
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) the shutdown state has been disabled by the PMEMOBJ_CONF environment variable"
 		exit 0
 	fi
 	return 0
@@ -1668,7 +1687,7 @@ function require_no_sds() {
 		grep -c "compiled with support for shutdown state")
 	set -e
 	if [ "$found" -ne "0" ]; then
-		msg "$UNITTEST_NAME: SKIP compiled with support for shutdown state"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) compiled with support for shutdown state"
 		exit 0
 	fi
 	return 0
@@ -1700,7 +1719,7 @@ function is_ndctl_enabled() {
 #
 function require_bb_enabled_by_default() {
 	if ! is_ndctl_enabled $1 &> /dev/null ; then
-		msg "$UNITTEST_NAME: SKIP bad block checking feature disabled by default"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) bad block checking feature disabled by default"
 		exit 0
 	fi
 
@@ -1715,7 +1734,7 @@ function require_bb_enabled_by_default() {
 #
 function require_bb_disabled_by_default() {
 	if is_ndctl_enabled $1 &> /dev/null ; then
-		msg "$UNITTEST_NAME: SKIP bad block checking feature enabled by default"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) bad block checking feature enabled by default"
 		exit 0
 	fi
 	return 0
@@ -1756,28 +1775,6 @@ function obj_pool_desc_size() {
 	echo "$(expr $(getconf PAGESIZE) \* 2)"
 }
 
-#
-# log_pool_desc_size -- returns the minimum size of pool header
-# in bytes which is two times the actual pagesize.
-#
-# This should be use to calculate the minimum zero size for pool
-# creation on some tests.
-#
-function log_pool_desc_size() {
-	echo "$(expr $(getconf PAGESIZE) \* 2)"
-}
-
-#
-# blk_pool_desc_size -- returns the minimum size of pool header
-# in bytes which is two times the actual pagesize.
-#
-# This should be use to calculate the minimum zero size for pool
-# creation on some tests.
-#
-function blk_pool_desc_size() {
-	echo "$(expr $(getconf PAGESIZE) \* 2)"
-}
-
 #
 # require_mmap_under_valgrind -- only allow script to continue if mapping is
 #				possible under Valgrind with required length
@@ -1797,8 +1794,11 @@ function require_mmap_under_valgrind() {
 		fatal "$FILE_MAX_DAX_DEVICES not found. Run make test."
 	fi
 
+	# XXX The number of device DAXes available under this condition is dependent
+	# on the size and the order of device DAXes in the testconfig.sh file.
+	# https://github.com/pmem/pmdk/issues/5615
 	if [ "$REQUIRE_DAX_DEVICES" -gt "$(< $FILE_MAX_DAX_DEVICES)" ]; then
-		msg "$UNITTEST_NAME: SKIP: anonymous mmap under Valgrind not possible for $REQUIRE_DAX_DEVICES DAX device(s)."
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): anonymous mmap under Valgrind not possible for $REQUIRE_DAX_DEVICES DAX device(s)."
 		exit 0
 	fi
 }
@@ -1821,6 +1821,15 @@ function setup() {
 		fatal "error: required test type is not specified"
 	fi
 
+	# if no label is set
+	if [ "$set_test_labels_done" != "1" ]; then
+		# but some label is required then the test is skipped
+		if [ "$TEST_LABEL" ]; then
+			verbose_msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) test-label $TEST_LABEL required"
+			exit 0
+		fi
+	fi
+
 	# fs type "none" must be explicitly enabled
 	if [ "$FS" = "none" -a "$req_fs_type" != "1" ]; then
 		exit 0
@@ -1867,9 +1876,12 @@ function setup() {
 		lock_devdax
 	fi
 
-	export PMEMBLK_CONF="fallocate.at_create=0;"
-	export PMEMOBJ_CONF="fallocate.at_create=0;"
-	export PMEMLOG_CONF="fallocate.at_create=0;"
+	export PMEMOBJ_CONF="${PMEMOBJ_CONF};fallocate.at_create=0"
+
+	# disable SDS for non-pmem tests
+	if [ "$REAL_FS" = "non-pmem" ]; then
+		export PMEMOBJ_CONF="${PMEMOBJ_CONF};sds.at_create=0"
+	fi
 }
 
 #
@@ -1952,6 +1964,18 @@ function pass() {
 	fi
 }
 
+#
+# DISABLED -- print a message that the test has been intentionally disabled
+#	      and abandon test execution
+#
+function DISABLED() {
+	msg=$(interactive_yellow STDOUT "DISABLED")
+	if [ "$UNITTEST_LOG_LEVEL" -ge 1 ]; then
+		echo -e "$UNITTEST_NAME: $msg ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM)"
+	fi
+	exit 0
+}
+
 # Length of pool file's signature
 SIG_LEN=8
 
@@ -1959,15 +1983,6 @@ SIG_LEN=8
 LAYOUT_OFFSET=$(getconf PAGE_SIZE)
 LAYOUT_LEN=1024
 
-# Length of arena's signature
-ARENA_SIG_LEN=16
-
-# Signature of BTT Arena
-ARENA_SIG="BTT_ARENA_INFO"
-
-# Offset to first arena
-ARENA_OFF=$(($(getconf PAGE_SIZE) * 2))
-
 #
 # check_file -- check if file exists and print error message if not
 #
@@ -2106,26 +2121,12 @@ check_layout()
 	fi
 }
 
-#
-# check_arena -- check if file contains specified arena signature
-#
-check_arena()
-{
-	local file=$1
-	local sig=$($DD if=$file bs=1 skip=$ARENA_OFF count=$ARENA_SIG_LEN 2>/dev/null | tr -d \\0)
-
-	if [[ $sig != $ARENA_SIG ]]
-	then
-		fatal "error: can't find arena signature"
-	fi
-}
-
 #
 # dump_pool_info -- dump selected pool metadata and/or user data
 #
 function dump_pool_info() {
 	# ignore selected header fields that differ by definition
-	${PMEMPOOL}.static-nondebug info $* | sed -e "/^UUID/,/^Checksum/d"
+	${PMEMPOOL}.static_nondebug info $* | sed -e "/^UUID/,/^Checksum/d"
 }
 
 #
@@ -2224,7 +2225,7 @@ function require_pmemcheck_version_ge()
 		fi
 	fi
 
-	msg "$UNITTEST_NAME: SKIP pmemcheck API version:" \
+	msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) pmemcheck API version:" \
 		"$PMEMCHECK_MAJOR.$PMEMCHECK_MINOR" \
 		"is less than required" \
 		"$REQUIRE_MAJOR.$REQUIRE_MINOR"
@@ -2258,7 +2259,7 @@ function require_pmemcheck_version_lt()
 		fi
 	fi
 
-	msg "$UNITTEST_NAME: SKIP pmemcheck API version:" \
+	msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) pmemcheck API version:" \
 		"$PMEMCHECK_MAJOR.$PMEMCHECK_MINOR" \
 		"is greater or equal than" \
 		"$REQUIRE_MAJOR.$REQUIRE_MINOR"
@@ -2283,7 +2284,7 @@ function require_python3()
 		return
 		;;
 	    *)
-		msg "$UNITTEST_NAME: SKIP: required python version 3"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): required python version 3"
 		exit 0
 		;;
 	esac
@@ -2428,11 +2429,11 @@ function require_free_space() {
 		row=$(echo "$output" | tail -1)
 		free_space=$(( $(echo $row | awk "{print \$$i}")*1024 ))
 	else
-		msg "$UNITTEST_NAME: SKIP: unable to check free space"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): unable to check free space"
 		exit 0
 	fi
 	if [ $free_space -lt $req_free_space ]; then
-		msg "$UNITTEST_NAME: SKIP: not enough free space ($1 required)"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): not enough free space ($1 required)"
 		exit 0
 	fi
 }
@@ -2446,7 +2447,7 @@ function require_max_devdax_size() {
 	cur_sz=$(get_devdax_size 0)
 	max_size=$2
 	if [ $cur_sz -ge $max_size ]; then
-		msg "$UNITTEST_NAME: SKIP: DevDAX $1 is too big for this test (max $2 required)"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): DevDAX $1 is too big for this test (max $2 required)"
 		exit 0
 	fi
 }
@@ -2460,7 +2461,7 @@ function require_max_block_size() {
 	cur_sz=$(stat --file-system --format=%S $1)
 	max_size=$2
 	if [ $cur_sz -gt $max_size ]; then
-		msg "$UNITTEST_NAME: SKIP: block size of $1 is too big for this test (max $2 required)"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): block size of $1 is too big for this test (max $2 required)"
 		exit 0
 	fi
 }
@@ -2504,7 +2505,7 @@ function require_badblock_tests_enabled() {
 		fi
 
 	else
-		msg "$UNITTEST_NAME: SKIP: bad block tests are not enabled in testconfig.sh"
+		msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM): bad block tests are not enabled in testconfig.sh"
 		exit 0
 	fi
 }
@@ -2589,3 +2590,20 @@ function turn_on_checking_bad_blocks()
 
 	expect_normal_exit "$PMEMPOOL feature -e CHECK_BAD_BLOCKS $FILE &>> $PREP_LOG_FILE"
 }
+
+#
+# set_test_labels -- if a certain label is required the test will be run only if
+#                    it is marked with the required label
+#
+function set_test_labels() {
+	set_test_labels_done=1
+	# no label has been required
+	[ "$TEST_LABEL" == "" ] && return
+	# a label has been required
+	for label in $*
+	do
+		[ "$label" == "$TEST_LABEL" ] && return
+	done
+	verbose_msg "$UNITTEST_NAME: SKIP ($TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM) test-labels: $* ($TEST_LABEL required)"
+	exit 0
+}
