@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2017-2020, Intel Corporation */
+/* Copyright 2017-2023, Intel Corporation */
 
 /*
  * util_sds.c -- unit test for shutdown state functions
@@ -58,7 +58,7 @@ main(int argc, char *argv[])
 		struct pmem2_source *src;
 		PMEM2_SOURCE_FROM_FD(&src, fds[i]);
 
-		if (pmem2_map(cfg, src, &maps[i])) {
+		if (pmem2_map_new(&maps[i], cfg, src)) {
 			UT_FATAL("pmem2_map: %s", pmem2_errormsg());
 		}
 
@@ -114,7 +114,7 @@ main(int argc, char *argv[])
 	FAIL(fail_on, 6);
 
 out:	for (unsigned i = 0; i < files; i++) {
-		pmem2_unmap(&maps[i]);
+		pmem2_map_delete(&maps[i]);
 		CLOSE(fds[i]);
 	}
 
@@ -177,8 +177,3 @@ os_part_deep_common(struct pool_replica *rep, unsigned partidx, void *addr,
 	persist(addr, len);
 	return 0;
 }
-
-#ifdef _MSC_VER
-MSVC_CONSTR(libpmem2_init)
-MSVC_DESTR(libpmem2_fini)
-#endif
