@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2014-2023, Intel Corporation */
+/* Copyright 2014-2024, Intel Corporation */
 
 /*
  * common.c -- definitions of common functions
@@ -26,10 +26,7 @@
 
 #include "output.h"
 #include "libpmem.h"
-#include "libpmemblk.h"
-#include "libpmemlog.h"
 #include "libpmemobj.h"
-#include "btt.h"
 #include "file.h"
 #include "os.h"
 #include "set.h"
@@ -44,49 +41,27 @@
 typedef const char *(*enum_to_str_fn)(enum chunk_type);
 
 /*
- * pmem_pool_type -- return pool type based on first two pages.
- * If pool header's content suggests that pool may be BTT device
- * (first page zeroed and no correct signature for pool header),
- * signature from second page is checked to prove that it's BTT device layout.
+ * pmem_pool_type -- return pool type based on the first page.
  */
 pmem_pool_type_t
 pmem_pool_type(const void *base_pool_addr)
 {
 	struct pool_hdr *hdrp = (struct pool_hdr *)base_pool_addr;
 
-	if (util_is_zeroed(hdrp, DEFAULT_HDR_SIZE)) {
-		return util_get_pool_type_second_page(base_pool_addr);
-	}
-
-	pmem_pool_type_t type = pmem_pool_type_parse_hdr(hdrp);
-	if (type != PMEM_POOL_TYPE_UNKNOWN)
-		return type;
-	else
-		return util_get_pool_type_second_page(base_pool_addr);
+	return pmem_pool_type_parse_hdr(hdrp);
 }
 
 /*
  * pmem_pool_checksum -- return true if checksum is correct
- * based on first two pages
+ * based on the first page
  */
 int
 pmem_pool_checksum(const void *base_pool_addr)
 {
-	/* check whether it's btt device -> first page zeroed */
-	if (util_is_zeroed(base_pool_addr, DEFAULT_HDR_SIZE)) {
-		struct btt_info bttinfo;
-		void *sec_page_addr = (char *)base_pool_addr + DEFAULT_HDR_SIZE;
-		memcpy(&bttinfo, sec_page_addr, sizeof(bttinfo));
-		btt_info_convert2h(&bttinfo);
-		return util_checksum(&bttinfo, sizeof(bttinfo),
-			&bttinfo.checksum, 0, 0);
-	} else {
-		/* it's not btt device - first page contains header */
-		struct pool_hdr hdrp;
-		memcpy(&hdrp, base_pool_addr, sizeof(hdrp));
-		return util_checksum(&hdrp, sizeof(hdrp),
-			&hdrp.checksum, 0, POOL_HDR_CSUM_END_OFF(&hdrp));
-	}
+	struct pool_hdr hdrp;
+	memcpy(&hdrp, base_pool_addr, sizeof(hdrp));
+	return util_checksum(&hdrp, sizeof(hdrp),
+		&hdrp.checksum, 0, POOL_HDR_CSUM_END_OFF(&hdrp));
 }
 
 /*
@@ -95,11 +70,7 @@ pmem_pool_checksum(const void *base_pool_addr)
 pmem_pool_type_t
 pmem_pool_type_parse_hdr(const struct pool_hdr *hdrp)
 {
-	if (memcmp(hdrp->signature, LOG_HDR_SIG, POOL_HDR_SIG_LEN) == 0)
-		return PMEM_POOL_TYPE_LOG;
-	else if (memcmp(hdrp->signature, BLK_HDR_SIG, POOL_HDR_SIG_LEN) == 0)
-		return PMEM_POOL_TYPE_BLK;
-	else if (memcmp(hdrp->signature, OBJ_HDR_SIG, POOL_HDR_SIG_LEN) == 0)
+	if (memcmp(hdrp->signature, OBJ_HDR_SIG, POOL_HDR_SIG_LEN) == 0)
 		return PMEM_POOL_TYPE_OBJ;
 	else
 		return PMEM_POOL_TYPE_UNKNOWN;
@@ -111,40 +82,13 @@ pmem_pool_type_parse_hdr(const struct pool_hdr *hdrp)
 pmem_pool_type_t
 pmem_pool_type_parse_str(const char *str)
 {
-	if (strcmp(str, "blk") == 0) {
-		return PMEM_POOL_TYPE_BLK;
-	} else if (strcmp(str, "log") == 0) {
-		return PMEM_POOL_TYPE_LOG;
-	} else if (strcmp(str, "obj") == 0) {
+	if (strcmp(str, "obj") == 0) {
 		return PMEM_POOL_TYPE_OBJ;
-	} else if (strcmp(str, "btt") == 0) {
-		return PMEM_POOL_TYPE_BTT;
 	} else {
 		return PMEM_POOL_TYPE_UNKNOWN;
 	}
 }
 
-/*
- * util_get_pool_type_second_page -- return type based on second page content
- */
-pmem_pool_type_t
-util_get_pool_type_second_page(const void *pool_base_addr)
-{
-	struct btt_info bttinfo;
-
-	void *sec_page_addr = (char *)pool_base_addr + DEFAULT_HDR_SIZE;
-	memcpy(&bttinfo, sec_page_addr, sizeof(bttinfo));
-	btt_info_convert2h(&bttinfo);
-
-	if (util_is_zeroed(&bttinfo, sizeof(bttinfo)))
-		return PMEM_POOL_TYPE_UNKNOWN;
-
-	if (memcmp(bttinfo.sig, BTTINFO_SIG, BTTINFO_SIG_LEN) == 0)
-		return PMEM_POOL_TYPE_BTT;
-
-	return PMEM_POOL_TYPE_UNKNOWN;
-}
-
 /*
  * util_parse_mode -- parse file mode from octal string
  */
@@ -404,7 +348,7 @@ util_parse_ranges(const char *ptr, struct ranges *rangesp, struct range entire)
 			*next = '\0';
 			next++;
 		}
-		struct range range;
+		struct range range = {0};
 		if (util_parse_range(str, &range, entire)) {
 			ret = -1;
 			goto out;
@@ -425,10 +369,6 @@ uint64_t
 pmem_pool_get_min_size(pmem_pool_type_t type)
 {
 	switch (type) {
-	case PMEM_POOL_TYPE_LOG:
-		return PMEMLOG_MIN_POOL;
-	case PMEM_POOL_TYPE_BLK:
-		return PMEMBLK_MIN_POOL;
 	case PMEM_POOL_TYPE_OBJ:
 		return PMEMOBJ_MIN_POOL;
 	default:
@@ -639,10 +579,7 @@ pmem_pool_parse_params(const char *fname, struct pmem_pool_params *paramsp,
 
 	paramsp->is_checksum_ok = pmem_pool_checksum(addr);
 
-	if (paramsp->type == PMEM_POOL_TYPE_BLK) {
-		struct pmemblk *pbp = addr;
-		paramsp->blk.bsize = le32toh(pbp->bsize);
-	} else if (paramsp->type == PMEM_POOL_TYPE_OBJ) {
+	if (paramsp->type == PMEM_POOL_TYPE_OBJ) {
 		struct pmemobjpool *pop = addr;
 		memcpy(paramsp->obj.layout, pop->layout, PMEMOBJ_MAX_LAYOUT);
 	}
@@ -1367,7 +1304,7 @@ util_pool_clear_badblocks(const char *path, int create)
 	int ret = util_poolset_create_set(&setp, path, 0, 0,
 						POOL_OPEN_IGNORE_SDS);
 	if (ret < 0) {
-		LOG(2, "cannot open pool set -- '%s'", path);
+		CORE_LOG_ERROR("cannot open pool set -- '%s'", path);
 		return -1;
 	}
 
