@@ -60,7 +60,6 @@ static const struct option long_options[] = {
 static void
 help_help(const char *appname)
 {
-	printf("NOTE: pmem blk and log pools are deprecated\n");
 	printf("Usage: %s help <command>\n", appname);
 }
 
@@ -164,7 +163,6 @@ static const struct command commands[] = {
 static void
 print_version(const char *appname)
 {
-	printf("NOTE: pmem blk and log pools are deprecated\n");
 	printf("%s %s\n", appname, SRCVERSION);
 }
 
@@ -222,19 +220,6 @@ main(int argc, char *argv[])
 	int opt;
 	int option_index;
 	int ret = 0;
-#ifdef _WIN32
-	util_suppress_errmsg();
-	wchar_t **wargv = CommandLineToArgvW(GetCommandLineW(), &argc);
-	for (int i = 0; i < argc; i++) {
-		argv[i] = util_toUTF8(wargv[i]);
-		if (argv[i] == NULL) {
-			for (i--; i >= 0; i--)
-				free(argv[i]);
-			outv_err("Error during arguments conversion\n");
-			return 1;
-		}
-	}
-#endif
 
 	common_init(PMEMPOOL_TOOL_LOG_PREFIX,
 			PMEMPOOL_TOOL_LOG_LEVEL_VAR,
@@ -278,10 +263,6 @@ end:
 
 	common_fini();
 
-#ifdef _WIN32
-	for (int i = argc; i > 0; i--)
-		free(argv[i - 1]);
-#endif
 	if (ret)
 		return 1;
 
