@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2014-2023, Intel Corporation
+# Copyright 2014-2024, Intel Corporation
 
 #
 # build-dpkg.sh - Script for building deb packages
@@ -292,7 +292,7 @@ Section: libs
 Priority: optional
 Standards-version: 4.1.4
 Build-Depends: debhelper (>= 9)
-Homepage: https://pmem.io/pmdk/
+Homepage: https://github.com/pmem/pmdk
 
 Package: libpmem
 Architecture: any
@@ -311,36 +311,6 @@ Description: Development files for libpmem
  for the persistent memory instructions for flushing changes to pmem is
  provided.
 
-Package: libpmemblk
-Architecture: any
-Depends: libpmem (=\${binary:Version}), \${shlibs:Depends}, \${misc:Depends}
-Description: Persistent Memory block array support library
- libpmemblk implements a pmem-resident array of blocks, all the same size, where
- a block is updated atomically with respect to power failure or program
- interruption (no torn blocks).
-
-Package: libpmemblk-dev
-Section: libdevel
-Architecture: any
-Depends: libpmemblk (=\${binary:Version}), libpmem-dev, \${shlibs:Depends}, \${misc:Depends}
-Description: Development files for libpmemblk
- libpmemblk implements a pmem-resident array of blocks, all the same size, where
- a block is updated atomically with respect to power failure or program
- interruption (no torn blocks).
-
-Package: libpmemlog
-Architecture: any
-Depends: libpmem (=\${binary:Version}), \${shlibs:Depends}, \${misc:Depends}
-Description: Persistent Memory log file support library
- libpmemlog implements a pmem-resident log file.
-
-Package: libpmemlog-dev
-Section: libdevel
-Architecture: any
-Depends: libpmemlog (=\${binary:Version}), libpmem-dev,  \${shlibs:Depends}, \${misc:Depends}
-Description: Development files for libpmemlog
- libpmemlog implements a pmem-resident log file.
-
 Package: libpmemobj
 Architecture: any
 Depends: libpmem (=\${binary:Version}), \${shlibs:Depends}, \${misc:Depends}
@@ -367,8 +337,8 @@ Depends: libpmem (=\${binary:Version}), \${shlibs:Depends}, \${misc:Depends}
 Description: Persistent Memory pool management support library
  libpmempool provides a set of utilities for management, diagnostics and repair
  of persistent memory pools. A pool in this context means a pmemobj pool,
- pmemblk pool, pmemlog pool or BTT layout, independent of the underlying
- storage. The libpmempool is for applications that need high reliability or
+ independent of the underlying storage.
+ The libpmempool is for applications that need high reliability or
  built-in troubleshooting. It may be useful for testing and debugging purposes
  also.
 
@@ -387,7 +357,7 @@ Package: $PACKAGE_NAME-dbg
 Section: debug
 Priority: optional
 Architecture: any
-Depends: libpmem (=\${binary:Version}), libpmemblk (=\${binary:Version}), libpmemlog (=\${binary:Version}), libpmemobj (=\${binary:Version}), libpmempool (=\${binary:Version}), \${misc:Depends}
+Depends: libpmem (=\${binary:Version}), libpmemobj (=\${binary:Version}), libpmempool (=\${binary:Version}), \${misc:Depends}
 Description: Debug symbols for PMDK libraries
  Debug symbols for all PMDK libraries.
 
@@ -418,7 +388,7 @@ Description: tool to parse and replay pmemcheck logs
  whether files are in a consistent state.
 EOF
 
-cp LICENSE debian/copyright
+cp LICENSE.txt debian/copyright
 
 if [ -n "$NDCTL_ENABLE" ]; then
 	pass_ndctl_enable="NDCTL_ENABLE=$NDCTL_ENABLE"
@@ -508,78 +478,6 @@ libpmem-dev: package-has-unnecessary-activation-of-ldconfig-trigger
 
 EOF
 
-cat << EOF > debian/libpmemblk.install
-$LIB_DIR/libpmemblk.so.*
-EOF
-
-cat << EOF > debian/libpmemblk.lintian-overrides
-$ITP_BUG_EXCUSE
-new-package-should-close-itp-bug
-libpmemblk: package-name-doesnt-match-sonames
-EOF
-
-cat << EOF > debian/libpmemblk-dev.install
-$LIB_DIR/pmdk_debug/libpmemblk.a $LIB_DIR/pmdk_dbg/
-$LIB_DIR/pmdk_debug/libpmemblk.so $LIB_DIR/pmdk_dbg/
-$LIB_DIR/pmdk_debug/libpmemblk.so.* $LIB_DIR/pmdk_dbg/
-$LIB_DIR/libpmemblk.so
-$LIB_DIR/pkgconfig/libpmemblk.pc
-$INC_DIR/libpmemblk.h
-$MAN7_DIR/libpmemblk.7
-$MAN3_DIR/pmemblk_*.3
-EOF
-
-cat << EOF > debian/libpmemblk-dev.lintian-overrides
-$ITP_BUG_EXCUSE
-new-package-should-close-itp-bug
-# The following warnings are triggered by a bug in debhelper:
-# https://bugs.debian.org/204975
-postinst-has-useless-call-to-ldconfig
-postrm-has-useless-call-to-ldconfig
-# We do not want to compile with -O2 for debug version
-hardening-no-fortify-functions $LIB_DIR/pmdk_dbg/*
-# pmdk provides second set of libraries for debugging.
-# These are in /usr/lib/$arch/pmdk_dbg/, but still trigger ldconfig.
-# Related issue: https://github.com/pmem/issues/issues/841
-libpmemblk-dev: package-has-unnecessary-activation-of-ldconfig-trigger
-EOF
-
-cat << EOF > debian/libpmemlog.install
-$LIB_DIR/libpmemlog.so.*
-EOF
-
-cat << EOF > debian/libpmemlog.lintian-overrides
-$ITP_BUG_EXCUSE
-new-package-should-close-itp-bug
-libpmemlog: package-name-doesnt-match-sonames
-EOF
-
-cat << EOF > debian/libpmemlog-dev.install
-$LIB_DIR/pmdk_debug/libpmemlog.a $LIB_DIR/pmdk_dbg/
-$LIB_DIR/pmdk_debug/libpmemlog.so $LIB_DIR/pmdk_dbg/
-$LIB_DIR/pmdk_debug/libpmemlog.so.* $LIB_DIR/pmdk_dbg/
-$LIB_DIR/libpmemlog.so
-$LIB_DIR/pkgconfig/libpmemlog.pc
-$INC_DIR/libpmemlog.h
-$MAN7_DIR/libpmemlog.7
-$MAN3_DIR/pmemlog_*.3
-EOF
-
-cat << EOF > debian/libpmemlog-dev.lintian-overrides
-$ITP_BUG_EXCUSE
-new-package-should-close-itp-bug
-# The following warnings are triggered by a bug in debhelper:
-# https://bugs.debian.org/204975
-postinst-has-useless-call-to-ldconfig
-postrm-has-useless-call-to-ldconfig
-# We do not want to compile with -O2 for debug version
-hardening-no-fortify-functions $LIB_DIR/pmdk_dbg/*
-# pmdk provides second set of libraries for debugging.
-# These are in /usr/lib/$arch/pmdk_dbg/, but still trigger ldconfig.
-# Related issue: https://github.com/pmem/issues/issues/841
-libpmemlog-dev: package-has-unnecessary-activation-of-ldconfig-trigger
-EOF
-
 cat << EOF > debian/libpmemobj.install
 $LIB_DIR/libpmemobj.so.*
 EOF
@@ -712,13 +610,17 @@ echo "" >> debian/changelog
 tail -n1 $CHANGELOG_TMP >> debian/changelog
 rm $CHANGELOG_TMP
 
-# This is our first release but we do
+# Required for PMEMOBJ tests to not attempt creating an SDS which will fail
+# in the simulated test environment.
+PMEMOBJ_CONF='sds.at_create=0'
+
 debuild --preserve-envvar=EXTRA_CFLAGS_RELEASE \
 	--preserve-envvar=EXTRA_CFLAGS_DEBUG \
 	--preserve-envvar=EXTRA_CFLAGS \
 	--preserve-envvar=EXTRA_CXXFLAGS \
 	--preserve-envvar=EXTRA_LDFLAGS \
 	--preserve-envvar=NDCTL_ENABLE \
+	--preserve-envvar=PMEMOBJ_CONF \
 	-us -uc -b
 
 cd $OLD_DIR
