@@ -36,8 +36,6 @@ echo "Areas computed basing on the list of modified files: (see utils/check-area
 categorize core      -e "^src/core/"
 categorize pmem      -e "^src/libpmem/"     -e "^src/include/libpmem.h"
 categorize pmem2     -e "^src/libpmem2/"    -e "^src/include/libpmem2.h" -e "^src/include/libpmem2/"
-categorize log       -e "^src/libpmemlog/"  -e "^src/include/libpmemlog.h"
-categorize blk       -e "^src/libpmemblk/"  -e "^src/include/libpmemblk.h"
 categorize obj       -e "^src/libpmemobj/"  -e "^src/include/libpmemobj.h" -e "^src/include/libpmemobj/"
 categorize pool      -e "^src/libpmempool/" -e "^src/include/libpmempool.h" -e "^src/tools/pmempool/"
 categorize benchmark -e "^src/benchmarks/"
@@ -53,11 +51,7 @@ categorize common    -e "^src/common/" \
 			-e ".gitattributes" \
 			-e ".gitignore" \
 			-e "^.mailmap\$" \
-			-e "^src/PMDK.sln\$" \
-			-e "Makefile\$" \
-			-e "^src/freebsd/" \
-			-e "^src/windows/" \
-			-e "^src/include/pmemcompat.h"
+			-e "Makefile\$"
 
 echo
 echo "If the above list contains more than 1 entry, please consider splitting"
