@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2016-2022, Intel Corporation
+# Copyright 2016-2023, Intel Corporation
 
 #
 # Used to check whether all the commit messages in a pull request
@@ -29,13 +29,8 @@ if [[ $subject =~ ^Revert.* ]]; then
 	exit 0
 fi
 
-if [[ $body =~ "git-subtree-dir: src/deps/miniasync" ]]; then
-	# skip
-	exit 0
-fi
-
 # valid area names
-AREAS="pmem\|pmem2\|log\|blk\|obj\|pool\|set\|test\|benchmark\|examples\|doc\|core\|common\|daxio\|pmreorder"
+AREAS="pmem\|pmem2\|obj\|pool\|set\|test\|benchmark\|examples\|doc\|core\|common\|daxio\|pmreorder"
 
 prefix=$(echo $subject | sed -n "s/^\($AREAS\)\:.*/\1/p")
 
